@@ -219,7 +219,7 @@ static void
 fish_gobble (FishItem *fishitem)
 {
   clickgame_destroy_item(fishitem);
-  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+  gc_sound_play_ogg ("sounds/bubble.wav", NULL);
 
   gcomprisBoard->sublevel++;
   gc_score_set(gcomprisBoard->sublevel);
@@ -227,7 +227,7 @@ fish_gobble (FishItem *fishitem)
   if(gcomprisBoard->sublevel>=gcomprisBoard->number_of_sublevel) {
     gamewon = TRUE;
     clickgame_destroy_all_items();
-    gc_bonus_display(gamewon, BONUS_FLOWER);
+    gc_bonus_display(gamewon, GC_BONUS_FLOWER);
     return;
   }
   /* Drop a new item now to speed up the game */
@@ -284,7 +284,10 @@ canvas_event(GnomeCanvas *canvas, GdkEvent *event)
 		 if (gnome_canvas_get_item_at (canvas, mouse_x, mouse_y) !=
 		     g_slist_nth_data (fish->cur_frames, fish->currentItem) &&
 		     (dx > 0) ^ (fish->speed < 0))
-		   fish_reverse_direction (fish);
+		   {
+		     fish_reverse_direction (fish);
+		     gc_sound_play_ogg ("sounds/drip.wav", NULL);
+		   }
 		 else
 		   react += 1;
 	       }
@@ -486,12 +489,12 @@ static void clickgame_next_level()
 {
   static /*const*/ gchar *bglist[] =
     {
-      "clickgame/nur00523.jpg",
-      "clickgame/nur03006.jpg",
-      "clickgame/nur03011.jpg",
-      "clickgame/nur03010.jpg",
-      "clickgame/nur03013.jpg",
-      "clickgame/nur03505.jpg"
+      "opt/sea1.jpg",
+      "opt/sea2.jpg",
+      "opt/sea3.jpg",
+      "opt/sea4.jpg",
+      "opt/sea5.jpg",
+      "opt/sea6.jpg"
     };
 
   int bgx = gcomprisBoard->level - 1;
@@ -536,6 +539,18 @@ static void clickgame_animate_item(FishItem *fishitem)
 							     currentItem));
 }
 
+static void
+fish_escape (FishItem *fishitem)
+{
+  item2del_list = g_list_append (item2del_list, fishitem);
+  gc_sound_play_ogg ("sounds/youcannot.wav", NULL);
+
+  if (gcomprisBoard->sublevel) {
+    --gcomprisBoard->sublevel;
+    gc_score_set(gcomprisBoard->sublevel);
+  }
+}
+
 static void clickgame_move_item(FishItem *fishitem)
 {
   double sp = fishitem->speed;
@@ -561,17 +576,13 @@ static void clickgame_move_item(FishItem *fishitem)
 
   if(fishitem->speed>0)
     {
-      if(x1>gcomprisBoard->width) {
-	item2del_list = g_list_append (item2del_list, fishitem);
-	gc_sound_play_ogg ("crash", NULL);
-      }
+      if(x1>gcomprisBoard->width)
+	fish_escape (fishitem);
     }
   else
     {
-      if(x2<0) {
-	item2del_list = g_list_append (item2del_list, fishitem);
-	gc_sound_play_ogg ("crash", NULL);
-      }
+      if(x2<0)
+	fish_escape (fishitem);
     }
 
   while (g_list_length (item_list) < 3) {
@@ -720,7 +731,7 @@ clickgame_create_item()
 
   fishitem = g_malloc(sizeof(FishItem));
   fishitem->currentItem   = 0;
-  fishitem->speed = (double)(rand()%(60))/10 - 3;
+  fishitem->speed = (double)(g_random_int()%(60))/10 - 3;
   fishitem->fright = 0;
   fishitem->stun = 0;
   fishitem->fwd_frames = NULL;
@@ -746,7 +757,7 @@ clickgame_create_item()
     gnome_canvas_item_new (parent,
 			   gnome_canvas_group_get_type (),
 			   "x", x,
-			   "y", (double)(rand()%(gcomprisBoard->height-
+			   "y", (double)(g_random_int()%(gcomprisBoard->height-
 						 (guint)(gdk_pixbuf_get_height(pixmap)*
 							 imageZoom))),
 			   NULL);
@@ -833,11 +844,10 @@ static void game_won()
     gcomprisBoard->sublevel=0;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   clickgame_next_level();
 }
-
