@@ -158,7 +158,6 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gamewon = FALSE;
       pause_board(FALSE);
 
-      gc_cursor_set(GCOMPRIS_LINE_CURSOR);
     }
 
 }
@@ -174,7 +173,6 @@ end_board ()
       destroy_all_items();
     }
   gcomprisBoard = NULL;
-  gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
 }
 
 static void
@@ -623,10 +621,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   clockgame_next_level();
 }
@@ -643,7 +641,7 @@ static void process_ok()
       /* Oups, you're wrong */
       gamewon = FALSE;
     }
-  gc_bonus_display(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, GC_BONUS_FLOWER);
 }
 
 
@@ -667,6 +665,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   switch (event->type)
     {
     case GDK_BUTTON_PRESS:
+      gc_sound_play_ogg ("sounds/bleep.wav", NULL);
       x = item_x;
       y = item_y;
 
@@ -701,10 +700,16 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  else if(item==minute_item)
 	  {
 	    if(currentTime.minute > 45 && angle * 30 / M_PI < 15)
-	      currentTime.hour++;
+	      {
+		currentTime.hour++;
+		gc_sound_play_ogg ("sounds/paint1.wav", NULL);
+	      }
 
 	    if(currentTime.minute < 15 && angle * 30 / M_PI > 45)
-	      currentTime.hour--;
+	      {
+		currentTime.hour--;
+		gc_sound_play_ogg ("sounds/paint1.wav", NULL);
+	      }
 
 	    display_minute(angle * 30 / M_PI);
 	    display_hour(currentTime.hour);
@@ -712,10 +717,16 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  else if(item==second_item)
 	  {
 	    if(currentTime.second > 45 && angle * 30 / M_PI < 15)
-	      currentTime.minute++;
+	      {
+		currentTime.minute++;
+		gc_sound_play_ogg ("sounds/paint1.wav", NULL);
+	      }
 
 	    if(currentTime.second < 15 && angle * 30 / M_PI > 45)
-	      currentTime.minute--;
+	      {
+		currentTime.minute--;
+		gc_sound_play_ogg ("sounds/paint1.wav", NULL);
+	      }
 
 	    display_second(angle * 30 / M_PI);
 	    display_minute(currentTime.minute);
@@ -746,21 +757,21 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 static void get_random_hour(GcomprisTime *time)
 {
 
-  time->hour=rand()%12;
+  time->hour=g_random_int()%12;
 
   if(gcomprisBoard->level>3)
-    time->second=rand()%60;
+    time->second=g_random_int()%60;
   else time->second=0;
 
-  time->minute=rand()%60;
+  time->minute=g_random_int()%60;
 
   switch(gcomprisBoard->level)
     {
     case 1:
-      time->minute=rand()%4*15;
+      time->minute=g_random_int()%4*15;
       break;
     case 2:
-      time->minute=rand()%12*5;
+      time->minute=g_random_int()%12*5;
       break;
     default:
       break;
