@@ -24,8 +24,14 @@
 #define SOUNDLISTFILE PACKAGE
 #define MAX_LAYERS 3
 
+typedef struct  {gint count; gint max;} counter;
+
 static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
+static SoundPolicy sound_policy;
+static GdkPixbuf *CoverPixmap[MAX_LAYERS];
+static gulong event_handle_id;
+
 
 static void	 start_board (GcomprisBoard *agcomprisBoard);
 static void	 pause_board (gboolean pause);
@@ -37,68 +43,67 @@ static void	 game_won(void);
 
 static GnomeCanvasGroup *boardRootItem = NULL;
 
-static GnomeCanvasItem	*erase_create_item(int layer);
+static GnomeCanvasItem	*erase_create_item();
 static void		 erase_destroy_all_items(void);
 static void		 erase_next_level(void);
 static gint		 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
 static void		 shuffle_image_list(char *list[], int size);
+static gint              canvas_event(GnomeCanvas *canvas, GdkEvent *event);
 
-static int number_of_item = 0;
+static int number_of_items = 0;
 static int number_of_item_x = 0;
 static int number_of_item_y = 0;
+static int *items_per_cell = 0;
+static guint normal_delay_id = 0;
 
 static gint timer_id = 0;
 
-// Default Double click distance to restore on exit.
-static gint DefaultDoubleClicDistance;
-
-static gint DoubleClicLevel[6]= {  1000, 750, 600, 500, 400, 250};
-
 #define NORMAL 0
 #define CLIC   1
-#define DOUBLECLIC 2
 
 static gint board_mode =  NORMAL;
 
 // List of images to use in the game
 static gchar *imageList[] =
   {
-    "gcompris/animals/bear001.jpg",
-    "gcompris/animals/black-headed-gull.jpg",
-    "gcompris/animals/butterfly.jpg",
-    "gcompris/animals/donkey.jpg",
-    "gcompris/animals/elephanteauxgc.jpg",
-    "gcompris/animals/flamentrosegc.jpg",
-    "gcompris/animals/girafegc.jpg",
-    "gcompris/animals/hypogc.jpg",
-    "gcompris/animals/joybear001.jpg",
-    "gcompris/animals/joybear002.jpg",
-    "gcompris/animals/jumentmulassieregc.jpg",
-    "gcompris/animals/malaybear002.jpg",
-    "gcompris/animals/pigeon.jpg",
-    "gcompris/animals/polabear011.jpg",
-    "gcompris/animals/polarbear001.jpg",
-    "gcompris/animals/poolbears001.jpg",
-    "gcompris/animals/rhinogc.jpg",
-    "gcompris/animals/singegc.jpg",
-    "gcompris/animals/spectbear001.jpg",
-    "gcompris/animals/tetegorillegc.jpg",
-    "gcompris/animals/tiger1_by_Ralf_Schmode.jpg",
-    "gcompris/animals/tigercub003.jpg",
-    "gcompris/animals/tigerdrink001.jpg",
-    "gcompris/animals/tigerplay001.jpg",
-    "gcompris/animals/horses.jpg",
-    "gcompris/animals/horses2.jpg",
-    "gcompris/animals/squirrel.jpg",
-    "gcompris/animals/sheep_irish.jpg",
-    "gcompris/animals/sheep_irish2.jpg",
-    "gcompris/animals/cow.jpg",
-    "gcompris/animals/maki1.jpg",
-    "gcompris/animals/maki2.jpg",
-    "gcompris/animals/maki3.jpg",
-    "gcompris/animals/maki4.jpg",
-    "gcompris/animals/maki5.jpg",
-    "gcompris/animals/maki6.jpg",
+    "opt/animals/bear001.jpg",
+    "opt/animals/black-headed-gull.jpg",
+    "opt/animals/butterfly.jpg",
+    "opt/animals/cat1.jpg",
+    "opt/animals/cat2.jpg",
+    "opt/animals/donkey.jpg",
+    "opt/animals/elephanteauxgc.jpg",
+    "opt/animals/flamentrosegc.jpg",
+    "opt/animals/girafegc.jpg",
+    "opt/animals/hypogc.jpg",
+    "opt/animals/joybear001.jpg",
+    "opt/animals/joybear002.jpg",
+    "opt/animals/jumentmulassieregc.jpg",
+    "opt/animals/malaybear002.jpg",
+    "opt/animals/pigeon.jpg",
+    "opt/animals/polabear011.jpg",
+    "opt/animals/polarbear001.jpg",
+    "opt/animals/poolbears001.jpg",
+    "opt/animals/rhinogc.jpg",
+    "opt/animals/singegc.jpg",
+    "opt/animals/spectbear001.jpg",
+    "opt/animals/tetegorillegc.jpg",
+    "opt/animals/tiger1_by_Ralf_Schmode.jpg",
+    "opt/animals/tigercub003.jpg",
+    "opt/animals/tigerdrink001.jpg",
+    "opt/animals/tigerplay001.jpg",
+    "opt/animals/horses.jpg",
+    "opt/animals/horses2.jpg",
+    "opt/animals/squirrel.jpg",
+    "opt/animals/sheep_irish.jpg",
+    "opt/animals/sheep_irish2.jpg",
+    "opt/animals/cow.jpg",
+    "opt/animals/maki1.jpg",
+    "opt/animals/maki2.jpg",
+    "opt/animals/maki3.jpg",
+    "opt/animals/maki4.jpg",
+    "opt/animals/maki5.jpg",
+    "opt/animals/maki6.jpg",
   };
 #define NUMBER_OF_IMAGES G_N_ELEMENTS(imageList)
 
@@ -172,34 +177,22 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=6;
       gcomprisBoard->sublevel=1;
       gcomprisBoard->number_of_sublevel=10; /* Go to next level after this number of 'play' */
-      gc_score_start(SCORESTYLE_NOTE,
-			   gcomprisBoard->width - 220,
-			   gcomprisBoard->height - 50,
-			   gcomprisBoard->number_of_sublevel);
       gc_bar_set(GC_BAR_LEVEL);
 
-      if (strcmp(gcomprisBoard->mode,"double_clic")==0)
-	board_mode = DOUBLECLIC;
-      else if (strcmp(gcomprisBoard->mode,"clic")==0)
+      /* CAUTION: CoverPixmap has MAX_LAYERS elements */
+      CoverPixmap[0] = gc_pixmap_load("images/transparent_square.png");
+      CoverPixmap[1] = gc_pixmap_load("images/transparent_square_green.png");
+      CoverPixmap[2] = gc_pixmap_load("images/transparent_square_yellow.png");
+
+      event_handle_id =
+	gtk_signal_connect(GTK_OBJECT(gcomprisBoard->canvas), "event",
+			   (GtkSignalFunc) canvas_event, 0);
+
+      if (strcmp(gcomprisBoard->mode,"clic")==0)
 	board_mode = CLIC;
-      else
+      else {
 	board_mode = NORMAL;
-
-      if (board_mode == DOUBLECLIC){
-	GtkSettings *DefaultsGtkSettings = gtk_settings_get_default ();
-
-	if (DefaultsGtkSettings == NULL) {
-	  g_warning("Couldn't get GTK settings");
-	} else {
-	  g_object_get(G_OBJECT(DefaultsGtkSettings),
-		       "gtk-double-click-time", &DefaultDoubleClicDistance, NULL);
-
-	  g_warning("Double-click default value %d.",DefaultDoubleClicDistance);
-	}
-
-	gdk_display_set_double_click_time( gdk_display_get_default(),
-					   DoubleClicLevel[gcomprisBoard->level-1]);
-	g_warning("Double-click value is now %d.",DoubleClicLevel[gcomprisBoard->level-1]);
+	gcomprisBoard->maxlevel=8;
       }
 
       current_image = 0;
@@ -209,23 +202,45 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       gamewon = FALSE;
       pause_board(FALSE);
+
+      /* initial state to restore */
+      sound_policy = gc_sound_policy_get();
+      gc_sound_policy_set(PLAY_AND_INTERRUPT);
+
+      GdkPixbuf *cursor_pixbuf = gc_pixmap_load("images/sponge.png");
+      if(cursor_pixbuf)
+	{
+	  GdkCursor *cursor = NULL;
+	  cursor = gdk_cursor_new_from_pixbuf(gdk_display_get_default(),
+					      cursor_pixbuf,
+					      gdk_pixbuf_get_width(cursor_pixbuf)/2,
+					      gdk_pixbuf_get_height(cursor_pixbuf)/2);
+	  gdk_window_set_cursor(gc_get_window()->window, cursor);
+	  gdk_cursor_unref(cursor);
+	  gdk_pixbuf_unref(cursor_pixbuf);
+	}
     }
 }
 /* ======================================= */
 static void end_board ()
 {
-  if (board_mode == DOUBLECLIC){
-    gdk_display_set_double_click_time( gdk_display_get_default(),
-					   DefaultDoubleClicDistance);
-    g_warning("Double click value is now %d.",DefaultDoubleClicDistance);
-  }
+  int i;
+  for(i=0; i<MAX_LAYERS; i++)
+    if(CoverPixmap[i]) {
+      gdk_pixbuf_unref(CoverPixmap[i]);
+      CoverPixmap[i]=NULL;
+    }
+
+  gc_cursor_set(GCOMPRIS_DEFAULT_CURSOR);
   if(gcomprisBoard!=NULL)
     {
+      gtk_signal_disconnect(GTK_OBJECT(gcomprisBoard->canvas),
+			    event_handle_id);
       pause_board(TRUE);
-      gc_score_end();
       erase_destroy_all_items();
     }
   gcomprisBoard = NULL;
+  gc_sound_policy_set(sound_policy);
 }
 
 /* ======================================= */
@@ -238,12 +253,6 @@ static void set_level (guint level)
       gcomprisBoard->sublevel=1;
       erase_next_level();
     }
-  if (board_mode == DOUBLECLIC){
-    gdk_display_set_double_click_time( gdk_display_get_default(),
-				       DoubleClicLevel[gcomprisBoard->level-1]);
-    g_warning("Double click value is now %d.",DoubleClicLevel[gcomprisBoard->level-1]);
-  }
-
 }
 /* ======================================= */
 static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
@@ -261,13 +270,28 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
   return FALSE;
 }
 
+static int get_num_layers()
+{
+  int layers;
+  /* Select the number of layer depending on the level */
+
+  if(gcomprisBoard->level>6)
+    layers = 4;
+  else if(gcomprisBoard->level>4)
+    layers = 3;
+  else if(gcomprisBoard->level>2)
+    layers = 2;
+  else
+    layers = 1;
+
+  return layers;
+}
+
 /*-------------------------------------------------------------------------------*/
 /*-------------------------------------------------------------------------------*/
 /* set initial values for the next level */
 static void erase_next_level()
 {
-  int layers = 1;
-
   gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
 			  imageList[current_image++]);
 
@@ -287,47 +311,95 @@ static void erase_next_level()
   } else {
     number_of_item_x = ((gcomprisBoard->level+1)%2+1)*5;
     number_of_item_y = ((gcomprisBoard->level+1)%2+1)*5;
-  }
-
-  /* Select the number of layer depending on the level */
-
-  if (board_mode != DOUBLECLIC){
-    if(gcomprisBoard->level>4)
-      layers = 3;
-    else if(gcomprisBoard->level>2)
-      layers = 2;
+    assert(!items_per_cell);
+    items_per_cell = g_new0(int, number_of_item_x * number_of_item_y);
   }
 
   /* Try the next level */
-  erase_create_item(layers);
-
-  gc_score_set(gcomprisBoard->sublevel);
-
+  erase_create_item();
 }
 
 /* ==================================== */
 /* Destroy all the items */
 static void erase_destroy_all_items()
 {
+  if (normal_delay_id) {
+    g_source_remove (normal_delay_id);
+    normal_delay_id = 0;
+  }
+
   if (timer_id) {
     gtk_timeout_remove (timer_id);
     timer_id = 0;
   }
 
-  if(boardRootItem!=NULL)
+  if(boardRootItem!=NULL) {
     gtk_object_destroy (GTK_OBJECT(boardRootItem));
+    boardRootItem = NULL;
+  }
 
-  boardRootItem = NULL;
+  number_of_items = 0;
+
+  if (items_per_cell) {
+    g_free(items_per_cell);
+    items_per_cell = NULL;
+  }
 }
+
+static void add_one_item(int i, int j, int protect)
+{
+  int current_layer = get_num_layers();
+  double w = (BOARDWIDTH/number_of_item_x) ;
+  double h = (BOARDHEIGHT/number_of_item_y) ;
+  int item_x = i / w;
+  int item_y = j / h;
+  i = item_x * w;
+  j = item_y * h;
+
+  if ((board_mode != NORMAL) && ((item_x+item_y) %2 == 0))
+    return;
+
+  if (current_layer == 4)
+    current_layer = 1;
+
+  while(current_layer--)
+    {
+      assert(CoverPixmap[current_layer]);
+      GnomeCanvasItem *item =
+	gnome_canvas_item_new (boardRootItem,
+				    gnome_canvas_pixbuf_get_type (),
+				    "pixbuf", CoverPixmap[current_layer],
+				    "x", (double) i,
+				    "y", (double) j,
+				    "width", w,
+				    "height", h,
+				    "width_set", TRUE,
+				    "height_set", TRUE,
+				    "anchor", GTK_ANCHOR_NW,
+				    NULL);
+
+      counter *c = g_new (counter, 1);
+      c->count = 0 ;
+      c->max = protect;
+      protect = 0; /* only protect the top item */
+
+      /* if item is not first, it must be keep first time mouse
+       * pass over in normal mode or in layer 4 */
+      if (current_layer > 0 || get_num_layers() == 4)
+	c->max += 1;
+
+      g_signal_connect_data (item, "event", (GCallback) item_event,(gpointer)c,
+			     (GClosureNotify) g_free, 0);
+      number_of_items++;
+      if (items_per_cell)
+	items_per_cell[item_x * number_of_item_x + item_y]++;
+    }
+}
+
 /* ==================================== */
-static GnomeCanvasItem *erase_create_item(int layer)
+static GnomeCanvasItem *erase_create_item()
 {
   int i,j;
-  int ix, jy;
-  GnomeCanvasItem *item = NULL;
-  GdkPixbuf *pixmap[MAX_LAYERS];
-
-  g_assert(layer<=MAX_LAYERS);
 
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -336,68 +408,22 @@ static GnomeCanvasItem *erase_create_item(int layer)
 							    "y", (double) 0,
 							    NULL));
 
-  number_of_item = 0;
+  assert(number_of_items == 0);
 
-  for(i=0; i<MAX_LAYERS; i++)
-    pixmap[i] = NULL;
-
-  if(layer>0)
-    pixmap[0] = gc_pixmap_load("images/transparent_square.png");
-
-  if(layer>1)
-    pixmap[1] = gc_pixmap_load("images/water_spot.png");
-
-  if(layer>2)
-    pixmap[2] = gc_pixmap_load("images/water_drop.png");
-
-  for(i=0,ix=0; i<BOARDWIDTH; i+=BOARDWIDTH/number_of_item_x, ix++)
-    {
-      for(j=0, jy=0; j<BOARDHEIGHT; j+=BOARDHEIGHT/number_of_item_y, jy++)
-	{
-	  int current_layer = layer;
-
-	  if ((board_mode != NORMAL) && ((ix+jy) %2 == 0))
-	    continue;
-
-	  while(current_layer--)
-	    {
-	      double w = (BOARDWIDTH/number_of_item_x) *  (1.0 - (0.3 * current_layer));
-	      double h = (BOARDHEIGHT/number_of_item_y) * (1.0 - (0.3 * current_layer));
-	      double x = i + ((BOARDWIDTH/number_of_item_x)  - w) / 2;
-	      double y = j + ((BOARDHEIGHT/number_of_item_y) - h) / 2;
-
-	      item = gnome_canvas_item_new (boardRootItem,
-					    gnome_canvas_pixbuf_get_type (),
-					    "pixbuf", pixmap[current_layer],
-					    "x", x,
-					    "y", y,
-					    "width", w,
-					    "height", h,
-					    "width_set", TRUE,
-					    "height_set", TRUE,
-					    "anchor", GTK_ANCHOR_NW,
-					    NULL);
-
-	      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event, NULL);
-	      number_of_item++;
-	    }
-	}
-    }
-
-  for(i=0; i<MAX_LAYERS; i++)
-    if(pixmap[i])
-      gdk_pixbuf_unref(pixmap[i]);
+  for(i=0; i<BOARDWIDTH; i+=BOARDWIDTH/number_of_item_x)
+    for(j=0; j<BOARDHEIGHT; j+=BOARDHEIGHT/number_of_item_y)
+      add_one_item(i, j, 0);
 
   return NULL;
 }
 
 static void bonus() {
-  gc_bonus_display(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, GC_BONUS_SMILEY);
   timer_id = 0;
 }
 
 static void finished() {
-  gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+  gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
   timer_id = 0;
 }
 
@@ -405,7 +431,6 @@ static void finished() {
 static void game_won()
 {
   gcomprisBoard->sublevel++;
-  gc_score_set(gcomprisBoard->sublevel);
 
   if(gcomprisBoard->sublevel>gcomprisBoard->number_of_sublevel) {
     /* Try the next level */
@@ -415,64 +440,99 @@ static void game_won()
       timer_id = gtk_timeout_add (2000, (GtkFunction) finished, NULL);
       return;
     }
-    if (board_mode == DOUBLECLIC){
-      gdk_display_set_double_click_time( gdk_display_get_default(),
-					 DoubleClicLevel[gcomprisBoard->level-1]);
-      g_warning("Double click value is now %d.", DoubleClicLevel[gcomprisBoard->level-1]);
-    }
-
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   erase_next_level();
 }
 
+static gboolean
+erase_one_item (GnomeCanvasItem *item)
+{
+  double screen_x, screen_y;
+  int x,y;
+  g_object_get(item, "x", &screen_x, "y", &screen_y, NULL);
+  x = screen_x / (BOARDWIDTH/number_of_item_x);
+  y = screen_y / (BOARDHEIGHT/number_of_item_y);
+  if (items_per_cell)
+    items_per_cell[(int) (x * number_of_item_x + y)]--;
+
+  gtk_object_destroy(GTK_OBJECT(item));
+
+  if(number_of_items%2)
+    gc_sound_play_ogg ("sounds/eraser1.wav", NULL);
+  else
+    gc_sound_play_ogg ("sounds/eraser2.wav", NULL);
+
+  if(--number_of_items == 0)
+    {
+      gamewon = TRUE;
+      erase_destroy_all_items();
+      timer_id = gtk_timeout_add (4000, (GtkFunction) bonus, NULL);
+    }
+  normal_delay_id = 0;
+  return FALSE;
+}
+
 /* ==================================== */
 static gint
 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
-
+  counter *c = (counter *) data;
   if(board_paused)
     return FALSE;
 
   if (event->type == GDK_MOTION_NOTIFY)
     return FALSE;
 
-  if (board_mode == NORMAL)
-    if (event->type != GDK_ENTER_NOTIFY)
-      return FALSE;
-
+  if (board_mode == NORMAL) {
+    if (event->type == GDK_ENTER_NOTIFY) {
+      if (c->count < c->max){
+	c->count++ ;
+	return FALSE ;
+      }
+      /* Are enter & leave always sent in pairs? Don't assume. */
+      if (normal_delay_id)
+	g_source_remove (normal_delay_id);
+      normal_delay_id
+	= g_timeout_add (50, (GSourceFunc) erase_one_item, item);
+    } else if (event->type == GDK_LEAVE_NOTIFY) {
+      if (normal_delay_id)
+	g_source_remove (normal_delay_id);
+      normal_delay_id = 0;
+    }
+    return FALSE;
+  }
   if (board_mode == CLIC)
     if (event->type != GDK_BUTTON_PRESS)
       return FALSE;
 
-  if (board_mode == DOUBLECLIC)
-    if ((event->type != GDK_BUTTON_PRESS) &
-	(event->type != GDK_2BUTTON_PRESS) &
-	(event->type != GDK_BUTTON_RELEASE))
-      return FALSE;
-
-
-  if (board_mode == DOUBLECLIC){
-    if (event->type == GDK_BUTTON_PRESS){
-      return FALSE;
-    }
-    if (event->type == GDK_BUTTON_RELEASE){
-      return FALSE;
-    }
-  }
-
-  gtk_object_destroy(GTK_OBJECT(item));
-
-  if(--number_of_item == 0)
-    {
-      gamewon = TRUE;
-      erase_destroy_all_items();
-      timer_id = gtk_timeout_add (4000, (GtkFunction) bonus, NULL);
-    }
+  erase_one_item (item);
 
   return FALSE;
 }
 
+static gint
+canvas_event(GnomeCanvas *canvas, GdkEvent *event)
+{
+  switch (event->type)
+    {
+    case GDK_BUTTON_PRESS:
+      if (board_mode == NORMAL) {
+	int x = event->button.x;
+	int y = event->button.y;
+	int item_x = x / (BOARDWIDTH/number_of_item_x);
+	int item_y = y / (BOARDHEIGHT/number_of_item_y);
+	if (items_per_cell[item_x * number_of_item_x + item_y] == 0)
+	  add_one_item(x, y, 1);
+      }
+      break;
+    default:
+      break;
+    }
+  return FALSE;
+}
+
+
 /** \brief shuffle_image_list, takes a char* array and it's length.
  *         it swaps a random number of items in it in order to provide
  *         the same list but in a random order.
@@ -484,15 +544,15 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 void shuffle_image_list(char *list[], int size)
 {
   int i;
+  char *olditem;
 
-  for(i=0; i<size; i++)
+  for(i=0; i < size - 1; i++)
     {
-      int random1 = RAND(0, size-1);
-      int random2 = RAND(0, size-1);
-      char *olditem;
+      int random1 = g_random_int_range(i, size-1);
+      if (i == random1) continue;
 
-      olditem = list[random2];
-      list[random2] = list[random1];
+      olditem = list[i];
+      list[i] = list[random1];
       list[random1] = olditem;
     }
 }
