@@ -28,8 +28,8 @@
 
 
 #define SOUNDLISTFILE PACKAGE
-#define MAX_MEMORY_WIDTH  7
-#define MAX_MEMORY_HEIGHT 6
+#define MAX_MEMORY_WIDTH  8
+#define MAX_MEMORY_HEIGHT 4
 
 //#define TEXT_FONT gc_skin_font_board_huge_bold
 #define TEXT_FONT "Serif bold 28"
@@ -167,11 +167,11 @@ static guint levelDescription[] =
   3,2,
   4,2,
   4,3,
-  4,4,
+  6,3,
   4,4,
   5,4,
   6,4,
-  6,5,
+  7,4,
   MAX_MEMORY_WIDTH,MAX_MEMORY_HEIGHT
 };
 
@@ -180,51 +180,31 @@ static MemoryItem *memoryArray[MAX_MEMORY_WIDTH][MAX_MEMORY_HEIGHT];
 /* List of images to use in the memory */
 static gchar *imageList[] =
 {
-  "gcompris/misc/apple.png",
-  "gcompris/misc/bicycle.png",
-  "gcompris/misc/bottle.png",
-  "gcompris/misc/carot.png",
-  "gcompris/misc/car.png",
-  "gcompris/misc/castle.png",
-  "gcompris/misc/cerise.png",
-  "gcompris/misc/cocotier.png",
-  "gcompris/misc/crown.png",
-  "gcompris/misc/egg.png",
-  "gcompris/misc/eggpot.png",
-  "gcompris/misc/fishingboat.png",
-  "gcompris/misc/flower.png",
-  "gcompris/misc/flowerpot.png",
-  "gcompris/misc/football.png",
-  "gcompris/misc/fusee.png",
-  "gcompris/misc/glass.png",
-  "gcompris/misc/house.png",
-  "gcompris/misc/lamp.png",
-  "gcompris/misc/lighthouse.png",
-  "gcompris/misc/light.png",
-  "gcompris/misc/minivan.png",
-  "gcompris/misc/peer.png",
-  "gcompris/misc/pencil.png",
-  "gcompris/misc/plane.png",
-  "gcompris/misc/postcard.png",
-  "gcompris/misc/postpoint.png",
-  "gcompris/misc/rape.png",
-  "gcompris/misc/raquette.png",
-  "gcompris/misc/sailingboat.png",
-  "gcompris/misc/sapin.png",
-  "gcompris/misc/sofa.png",
-  "gcompris/misc/star.png",
-  "gcompris/misc/strawberry.png",
-  "gcompris/misc/tree.png",
-  "gcompris/misc/truck.png",
-  "gcompris/misc/tuxplane.png",
-  "gcompris/misc/tux.png",
-  "gcompris/misc/windflag0.png",
-  "gcompris/misc/windflag4.png",
-  "gcompris/misc/windflag5.png",
+  "cardimage/01_cat.png",
+  "cardimage/02_pig.png",
+  "cardimage/03_bear.png",
+  "cardimage/04_hippopotamus.png",
+  "cardimage/05_penguin.png",
+  "cardimage/06_cow.png",
+  "cardimage/07_sheep.png",
+  "cardimage/08_turtle.png",
+  "cardimage/09_panda.png",
+  "cardimage/10_chicken.png",
+  "cardimage/11_redbird.png",
+  "cardimage/12_wolf.png",
+  "cardimage/13_monkey.png",
+  "cardimage/14_fox.png",
+  "cardimage/15_bluebirds.png",
+  "cardimage/16_elephant.png",
+  "cardimage/17_lion.png",
+  "cardimage/18_gnu.png",
+  "cardimage/19_bluebaby.png",
+  "cardimage/20_greenbaby.png",
+  "cardimage/21_frog.png",
 };
 #define NUMBER_OF_IMAGES G_N_ELEMENTS(imageList)
 
-/* List of images to use in the memory */
+/* List of sounds to use in the memory */
 static gchar *soundList[] =
 {
    "sounds/LuneRouge/animaux/LRRain_in_garden_01_by_Lionel_Allorge_cut.ogg",
@@ -522,7 +502,7 @@ void get_random_token(int token_type, gint *returned_type, gchar **string, gchar
 
   g_assert(max_token >0);
 
-  i = rand()%max_token;
+  i = g_random_int()%max_token;
 
   for (list = data; list != NULL; list = list->next)
     if ( i < ((DATUM *)list->data)->bound)
@@ -821,7 +801,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
 	  gc_sound_policy_set(PLAY_AND_INTERRUPT);
 
-	  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/gcompris_band.png");
+	  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+			    "opt/gcompris_band.png");
 	  base_x1 = BASE_SOUND_X1;
 	  base_y1 = BASE_SOUND_Y1;
 	  base_x2 = BASE_SOUND_X2;
@@ -836,7 +817,8 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	}
       else
 	{
-	  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
+	  gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+			    "opt/scenery_background.png");
 	  base_x1 = BASE_CARD_X1;
 	  base_y1 = BASE_CARD_Y1;
 	  base_x2 = BASE_CARD_X2;
@@ -860,7 +842,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       g_assert(g_utf8_validate(alphabet_uppercase,-1,NULL)); // require by all utf8-functions
       g_warning("Using uppercase %s", alphabet_uppercase);
 
-      /* TRANSLATORS: Put here the mathematical operators "+-" for  your language. */
+      /* TRANSLATORS: Put here the mathematical operators '+-x/' for  your language. */
       operators=_("+-×÷");
       g_assert(g_utf8_validate(operators,-1,NULL)); // require by all utf8-functions
       g_warning("Using operators %s", operators);
@@ -921,7 +903,7 @@ end_board ()
   g_free(op_minus);
   g_free(op_mult);
   g_free(op_div);
-  
+
   gcomprisBoard = NULL;
 }
 
@@ -1175,8 +1157,8 @@ static void get_image(MemoryItem *memoryItem, guint x, guint y)
 
 
   // Randomly set the pair
-  rx = (int)(numberOfColumn*((double)rand()/RAND_MAX));
-  ry = (int)(numberOfLine*((double)rand()/RAND_MAX));
+  rx = g_random_int_range( 0, numberOfColumn);
+  ry = g_random_int_range(0, numberOfLine);
 
   while(memoryArray[rx][ry])
     {
@@ -1201,14 +1183,17 @@ static void create_item(GnomeCanvasGroup *parent)
   gint height, width;
   gint height2, width2;
   GdkPixbuf *pixmap = NULL;
-  double xratio = 0;
-  double yratio = 0;
-  double card_shadow_w, card_shadow_h;
 
   // Calc width and height of one card
   width  = (base_x2-(currentMode == MODE_TUX ? base_x1_tux : base_x1))/numberOfColumn;
   height = (base_y2-base_y1)/numberOfLine;
 
+  // Respect the card ratio
+  if( width * 1.418 > height)
+    width = height * 0.704;
+  else
+    height = width * 1.418;
+
   /* Remove a little bit of space for the card shadow */
   height2 = height * 0.95;
   width2  = width  * 0.95;
@@ -1235,7 +1220,7 @@ static void create_item(GnomeCanvasGroup *parent)
 				 "y", (double) 20,
 				 NULL);
     gdk_pixbuf_unref(pixmap_tux);
-    
+
     tux_score_s = gnome_canvas_item_new (GNOME_CANVAS_GROUP(parent),
 				       gnome_canvas_text_get_type (),
 				       "font", gc_skin_font_board_huge_bold,
@@ -1290,7 +1275,7 @@ static void create_item(GnomeCanvasGroup *parent)
 	  if (currentUiMode == UIMODE_SOUND)
 	    pixmap = gc_pixmap_load("gcompris/misc/Tux_mute.png");
 	  else
-	    pixmap = gc_pixmap_load("gcompris/misc/backcard.png");
+	    pixmap = gc_pixmap_load("cardimage/backcard.png");
 
 	  memoryItem->backcardItem = \
 	    gnome_canvas_item_new (GNOME_CANVAS_GROUP(memoryItem->rootItem),
@@ -1306,7 +1291,7 @@ static void create_item(GnomeCanvasGroup *parent)
 	  gdk_pixbuf_unref(pixmap);
 
 	  if (currentUiMode != UIMODE_SOUND){
-	    pixmap = gc_pixmap_load("gcompris/misc/emptycard.png");
+	    pixmap = gc_pixmap_load("cardimage/emptycard.png");
 	    memoryItem->framecardItem = \
 	      gnome_canvas_item_new (GNOME_CANVAS_GROUP(memoryItem->rootItem),
 				     gnome_canvas_pixbuf_get_type (),
@@ -1345,24 +1330,16 @@ static void create_item(GnomeCanvasGroup *parent)
 	    if(memoryItem->type == TYPE_IMAGE) {
 	      pixmap = gc_pixmap_load(memoryItem->data);
 
-	      yratio=(height2*0.8)/(float)gdk_pixbuf_get_height(pixmap);
-	      xratio=(width2*0.8)/(float)gdk_pixbuf_get_width(pixmap);
-	      yratio=xratio=MIN(xratio, yratio);
-	      card_shadow_w = width*0.05;
-	      card_shadow_h = height*0.05;
-
 	      memoryItem->frontcardItem =	\
 		gnome_canvas_item_new (GNOME_CANVAS_GROUP(memoryItem->rootItem),
 				       gnome_canvas_pixbuf_get_type (),
 				       "pixbuf", pixmap,
-				       "x", (double) ((width2)-
-						      gdk_pixbuf_get_width(pixmap)*xratio*0.8)/2 -
-				       card_shadow_w,
-				       "y", (double) ((height2)-
-						      gdk_pixbuf_get_height(pixmap)*yratio*0.8)/2 -
-				       card_shadow_h,
-				       "width", (double) gdk_pixbuf_get_width(pixmap)*xratio*0.8,
-				       "height", (double) gdk_pixbuf_get_height(pixmap)*yratio*0.8,
+				       "x", (double) (width2-
+						      gdk_pixbuf_get_width(pixmap))/2,
+				       "y", (double) (height2-
+						      gdk_pixbuf_get_height(pixmap))/2,
+				       "width", (double) gdk_pixbuf_get_width(pixmap),
+				       "height", (double) gdk_pixbuf_get_height(pixmap),
 				       "width_set", TRUE,
 				       "height_set", TRUE,
 				       NULL);
@@ -1380,10 +1357,10 @@ static void create_item(GnomeCanvasGroup *parent)
 				       gnome_canvas_text_get_type (),
 				       "text", memoryItem->data,
 				       "font", font,
-				       "x", (double) (width2*0.9)/2,
-				       "y", (double) (height2*0.9)/2,
+				       "x", (double) (width2)/2,
+				       "y", (double) (height2)/2,
 				       "anchor", GTK_ANCHOR_CENTER,
-				       "fill_color_rgba", 0x559ADDFF,
+				       "fill_color_rgba", 0x225AFFFF,
 				       NULL);
 
 	    }
@@ -1402,15 +1379,15 @@ static void create_item(GnomeCanvasGroup *parent)
 
 static void player_win()
 {
-  gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+  gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   /* Try the next level */
   if (tux_pairs <= player_pairs)
     gcomprisBoard->level++;
   if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-    gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+    gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
     return;
   }
-  gc_bonus_display((tux_pairs <= player_pairs), BONUS_RANDOM);
+  gc_bonus_display((tux_pairs <= player_pairs), GC_BONUS_LION);
 
 }
 
@@ -1543,7 +1520,7 @@ static void check_win()
 
   // Check win
   if (compare_card((gpointer) firstCard, (gpointer) secondCard) == 0) {
-    gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+    gc_sound_play_ogg ("sounds/flip.wav", NULL);
     win_id = g_timeout_add (timeout,
 			    (GSourceFunc) hide_card, NULL);
     return;
@@ -1589,6 +1566,9 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MemoryItem *memoryItem)
 	   if(win_id)
 	     return FALSE;
 
+	   if (currentUiMode == UIMODE_NORMAL)
+	     gc_sound_play_ogg ("sounds/bleep.wav", NULL);
+
 	   if(secondCard)
 	     {
 	       display_card(firstCard, ON_BACK);
@@ -1735,7 +1715,7 @@ static gint tux_play(){
       if (currentUiMode == UIMODE_SOUND)
 	return FALSE;
       else {
-	gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+	gc_sound_play_ogg ("sounds/flip.wav", NULL);
 	win_id = g_timeout_add (1000,
 				(GSourceFunc) hide_card, NULL);
 	return TRUE;
@@ -1744,8 +1724,8 @@ static gint tux_play(){
   }
 
   // Randomly set the pair
-  rx = (int)(numberOfColumn*((double)rand()/RAND_MAX));
-  ry = (int)(numberOfLine*((double)rand()/RAND_MAX));
+  rx = g_random_int_range( 0, numberOfColumn);
+  ry = g_random_int_range(0, numberOfLine);
 
   gboolean  stay_unknown = (remainingCards > (g_queue_get_length (tux_memory)
 					      + (firstCard ? 1 : 0)));
@@ -1789,7 +1769,7 @@ static gint tux_play(){
       return FALSE;
     else {
       if (compare_card(firstCard, secondCard)==0){
-	gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+	gc_sound_play_ogg ("sounds/flip.wav", NULL);
 	g_warning("Now tux win !");
 	win_id = g_timeout_add (1000,
 				(GSourceFunc) hide_card, NULL);
@@ -1815,7 +1795,7 @@ static void sound_callback(gchar *file)
     if (to_tux) {
       if (firstCard && secondCard){
 	if (compare_card(firstCard, secondCard)==0){
-	  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+	  gc_sound_play_ogg ("sounds/gobble.wav", NULL);
 	  win_id = g_timeout_add (1000,
 				  (GSourceFunc) hide_card, NULL);
 	  tux_id = g_timeout_add (2000,
