@@ -157,12 +157,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
   if(agcomprisBoard!=NULL)
     {
-      gchar *img;
       gcomprisBoard=agcomprisBoard;
-      img = gc_skin_image_get("missingletter-bg.jpg");
       gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      img);
-      g_free(img);
+			"opt/missingletter-bg.jpg");
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=NUMBER_OF_LEVELS;
       gcomprisBoard->sublevel=1;
@@ -260,7 +257,6 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
   double dx1, dy1, dx2, dy2;
   GdkPixbuf *button_pixmap = NULL;
   GdkPixbuf *pixmap = NULL;
-  char *str = NULL;
 
   /* This are the values of the area in which we must display the image */
   gint img_area_x = 290;
@@ -275,7 +271,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
   board_number = (gcomprisBoard->level-1) * NUMBER_OF_SUBLEVELS + gcomprisBoard->sublevel-1;
 
   g_assert(board_number >= 0  && board_number < g_list_length(board_list));
-  place = ((int)(3.0*rand()/(RAND_MAX+1.0)));
+  place = g_random_int_range( 0, 3);
   g_assert(place >= 0  && place < 3);
 
   right_word = place+1;
@@ -290,8 +286,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
   /* display the image */
   board = g_list_nth_data(board_list, board_number);
   g_assert(board != NULL);
-  str = g_strdup_printf("%s/%s", "imageid"/*gcomprisBoard->boarddir*/, board->pixmapfile);
-  pixmap = gc_pixmap_load(str);
+  pixmap = gc_pixmap_load(board->pixmapfile);
 
   yOffset = (gcomprisBoard->height - gdk_pixbuf_get_height(button_pixmap) - gdk_pixbuf_get_height(pixmap) - 2*VERTICAL_SEPARATION)/2;
 
@@ -329,7 +324,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				      NULL);
   gtk_signal_connect(GTK_OBJECT(image_item), "event", (GtkSignalFunc) item_event, NULL);
   gdk_pixbuf_unref(pixmap);
-  g_free(str);
+
   /* display the 3 words */
   /* the right word is at position 0 : it is swapped with any position depending of place value */
 
@@ -451,7 +446,7 @@ static void game_won() {
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) {
-	gc_bonus_end_display(BOARD_FINISHED_TUXPLANE);
+	gc_bonus_end_display(GC_BOARD_FINISHED_TUXPLANE);
 	return;
     }
   }
@@ -460,7 +455,7 @@ static void game_won() {
 
 /* ==================================== */
 static gboolean process_ok_timeout() {
-  gc_bonus_display(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, GC_BONUS_FLOWER);
   return FALSE;
 }
 
@@ -615,6 +610,7 @@ static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 		printf("Error sscanf result != 5 = %i\n",i);
 */
   gchar **all_answer = g_strsplit(data, "/", 5);
+  /* Dont free data, it's a gettext static message */
 
   answer = all_answer[0];
   question = all_answer[1];
@@ -773,7 +769,7 @@ config_start(GcomprisBoard *agcomprisBoard,
   if (gcomprisBoard)
     pause_board(TRUE);
 
-  gchar *label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+  gchar *label = g_strdup_printf(_("<b>%s</b> configuration\n for profile <b>%s</b>"),
 				 agcomprisBoard->name,
 				 aProfile ? aProfile->name : "");
 
