@@ -1,6 +1,6 @@
 #ifndef _PY_MOD_TIMER_H_
 #define _PY_MOD_TIMER_H_
 
-void python_gcompris_timer_module_init(void);
+void python_gc_timer_module_init(void);
 
 #endif
