@@ -144,7 +144,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
       gc_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      "railroad/railroad-bg.png");
+			      "opt/railroad-bg.png");
 
       for (i=0; i<ENGINES; i++) {
       	str = g_strdup_printf("railroad/loco%d.png", i+1);
@@ -357,7 +357,7 @@ static GnomeCanvasItem *railroad_create_item(GnomeCanvasGroup *parent)
   model_size = gcomprisBoard->level +1; // engine + cars
   // First the cars, depending of the level
   for (i=0; i<model_size-1; i++) {
-    r = (int)(((float) WAGONS)*rand()/(RAND_MAX+1.0));
+    r = g_random_int_range( 0, WAGONS);
     g_assert( r >=0 && r < WAGONS);
     // keep track of the answer
     int_model_list = g_list_append(int_model_list, GINT_TO_POINTER(r+ENGINES));
@@ -373,7 +373,7 @@ static GnomeCanvasItem *railroad_create_item(GnomeCanvasGroup *parent)
   }
 
   // Then the engine
-  r = (int)(((float) ENGINES)*rand()/(RAND_MAX+1.0));
+  r = g_random_int_range( 0, ENGINES);
   g_assert( r >=0 && r < ENGINES);
   // keep track of the answer
   int_model_list = g_list_append(int_model_list, GINT_TO_POINTER(r));
@@ -399,10 +399,10 @@ static void game_won()
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-      gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+      gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
       return;
     }
-    gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+    gc_sound_play_ogg ("sounds/bonus.wav", NULL);
   }
   railroad_next_level();
 }
@@ -434,7 +434,7 @@ static void process_ok()
   for (i=0; i<g_list_length(int_model_list); i++)
     g_warning(" i = \t%d val = \t%d\n", i, GPOINTER_TO_INT(g_list_nth_data(int_model_list,i)) );
 
-  gc_bonus_display(gamewon, BONUS_FLOWER);
+  gc_bonus_display(gamewon, GC_BONUS_FLOWER);
 }
 /* ==================================== */
 static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
@@ -461,6 +461,7 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
     {
     case GDK_BUTTON_PRESS:
       g_warning("GDK_BUTTON_PRESS item %d\tlength answer = %d\n",item_number,g_list_length(item_answer_list));
+      gc_sound_play_ogg ("sounds/bleep.wav", NULL);
       xOffset = 0;
       for (i=0; i<g_list_length(item_answer_list); i++) {
 	gnome_canvas_item_get_bounds(g_list_nth_data(item_answer_list,i), &dx1, &dy1, &dx2, &dy2);
@@ -509,6 +510,7 @@ static gint answer_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   switch (event->type)
     {
     case GDK_BUTTON_PRESS:
+      gc_sound_play_ogg ("sounds/smudge.wav", NULL);
       g_warning("Deleting %d\n",item_number);
       local_item = g_list_nth_data(item_answer_list,item_number);
       item_answer_list = g_list_remove( item_answer_list, local_item );
@@ -615,7 +617,7 @@ static void animate_model() {
   animation_pending = TRUE;
   animation_count = 0;
 
-  gc_sound_play_ogg( "sounds/train.ogg", NULL );
+  gc_sound_play_ogg( "sounds/train.wav", NULL );
 
   // warning : if timeout is too low, the model will not be displayed
   timer_id = gtk_timeout_add (100, (GtkFunction) animate_step, NULL);
