@@ -127,7 +127,7 @@ static void pause_board (gboolean pause)
 static void start_board (GcomprisBoard *agcomprisBoard) {
   GList * list = NULL;
   int * item;
-  int i;
+  int i,list_length;
 
   if(agcomprisBoard!=NULL) {
     gcomprisBoard=agcomprisBoard;
@@ -148,8 +148,8 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
     for (i=0; i<LAST_COLOR; i++)
       list = g_list_append(list, GINT_TO_POINTER(i));
 
-    while ((g_list_length(list) > 0)) {
-      i = RAND(0,g_list_length(list)-1);
+    while ((list_length = g_list_length(list))) {
+      i = list_length == 1 ? 0 : g_random_int_range(0,g_list_length(list)-1);
       item = g_list_nth_data(list, i);
       listColors = g_list_append(listColors, item);
       list = g_list_remove(list, item);
@@ -315,7 +315,7 @@ static void game_won() {
   listColors = g_list_remove(listColors, g_list_nth_data(listColors,0));
 
   if( g_list_length(listColors) <= 0 ) { // the current board is finished : bail out
-    gc_bonus_end_display(BOARD_FINISHED_TUXLOCO);
+    gc_bonus_end_display(GC_BOARD_FINISHED_TUXLOCO);
     return;
   }
 
@@ -325,7 +325,7 @@ static void game_won() {
  *
  * =====================================================================*/
 static gboolean process_ok_timeout() {
-  gc_bonus_display(gamewon, BONUS_SMILEY);
+  gc_bonus_display(gamewon, GC_BONUS_SMILEY);
   if (!gamewon)
     errors--;
   if (errors <1)
@@ -333,7 +333,7 @@ static gboolean process_ok_timeout() {
   update_clock();
 
   if (errors <= 1) {
-    gc_bonus_end_display(BOARD_FINISHED_TOOMANYERRORS);
+    gc_bonus_end_display(GC_BOARD_FINISHED_TOOMANYERRORS);
   }
 
 	return FALSE;
@@ -371,6 +371,7 @@ static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
       }
 
       if (clicked >= 0) {
+	gc_sound_play_ogg ("sounds/bleep.wav", NULL);
 	board_paused = TRUE;
 	highlight_selected(clicked);
 	gamewon = (clicked == GPOINTER_TO_INT(g_list_nth_data(listColors,0)));
