@@ -1,6 +1,6 @@
 /* gcompris - wordsgame.c
  *
- * Time-stamp: <2006/08/22 02:23:24 bruno>
+ * Time-stamp: <2007-04-15 21:17:08 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -180,7 +180,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* disable im_context */
       //gcomprisBoard->disable_im_context = TRUE;
 
-      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery_background.png");
+      gc_set_background(gnome_canvas_root(gcomprisBoard->canvas), "opt/scenery_background.png");
 
 
       gcomprisBoard->level = 1;
@@ -636,7 +636,7 @@ static GnomeCanvasItem *wordsgame_create_item(GnomeCanvasGroup *parent)
                                    &x2,
                                    &y2);
 
-  gnome_canvas_item_move (item->rootitem,(double) (rand()%(gcomprisBoard->width-(gint)(x2))),(double) 0);
+  gnome_canvas_item_move (item->rootitem,(double) (g_random_int()%(gcomprisBoard->width-(gint)(x2))),(double) 0);
 
 
   g_static_rw_lock_writer_lock (&items_lock);
@@ -660,6 +660,7 @@ static void wordsgame_add_new_item()
  */
 static gint wordsgame_drop_items (GtkWidget *widget, gpointer data)
 {
+  gc_sound_play_ogg ("sounds/level.wav", NULL);
   wordsgame_add_new_item();
   g_source_remove(drop_items_id);
   drop_items_id = g_timeout_add (fallSpeed,(GtkFunction) wordsgame_drop_items, NULL);
@@ -670,7 +671,7 @@ static gint wordsgame_drop_items (GtkWidget *widget, gpointer data)
 static void player_win(LettersItem *item)
 {
 
-  gc_sound_play_ogg ("sounds/gobble.ogg", NULL);
+  gc_sound_play_ogg ("sounds/flip.wav", NULL);
 
   g_assert(gcomprisBoard!=NULL);
 
@@ -697,11 +698,11 @@ static void player_win(LettersItem *item)
       gcomprisBoard->level++;
       gcomprisBoard->sublevel = 0;
       if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-	gc_bonus_end_display(BOARD_FINISHED_RANDOM);
+	gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
 	return;
       }
       wordsgame_next_level();
-      gc_sound_play_ogg ("sounds/bonus.ogg", NULL);
+      gc_sound_play_ogg ("sounds/bonus.wav", NULL);
     }
   else
     {
@@ -737,5 +738,5 @@ static void player_win(LettersItem *item)
 
 static void player_loose()
 {
-  gc_sound_play_ogg ("sounds/crash.ogg", NULL);
+  gc_sound_play_ogg ("sounds/crash.wav", NULL);
 }
