@@ -1,6 +1,6 @@
 /* gcompris - bar.c
  *
- * Time-stamp: <2006/08/21 23:27:39 bruno>
+ * Time-stamp: <2007-04-15 21:03:40 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -488,6 +488,7 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
       break;
     case GDK_BUTTON_PRESS:
       bar_reset_sound_id();
+      gc_sound_play_ogg ("sounds/bleep.wav", NULL);
 
       /* This is not perfect clean but it makes it easy to remove the help window
 	 by clicking on any button in the bar */
@@ -508,9 +509,19 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 	{
 	  gint tmp = current_level;
 
-	  current_level++;
-	  if(current_level>gcomprisBoard->maxlevel)
-	    current_level=1;
+	  if(event->button.button == 1)
+	    {
+	      current_level++;
+	      if(current_level>gcomprisBoard->maxlevel)
+		current_level=1;
+	    }
+	  else
+	    {
+	      /* Decrease the level */
+	      current_level--;
+	      if(current_level<1)
+		current_level=1;
+	    }
 
 	  if(tmp!=current_level)
 	    {
@@ -526,22 +537,20 @@ item_event_bar(GnomeCanvasItem *item, GdkEvent *event, gchar *data)
 
 	      g_free(str_number);
 	      g_free(current_level_str);
-	    }
 
-	  if(gcomprisBoard->plugin->set_level != NULL)
-	    {
-	      gcomprisBoard->plugin->set_level(current_level);
+	      if(gcomprisBoard->plugin->set_level != NULL)
+		{
+		  gcomprisBoard->plugin->set_level(current_level);
+		}
 	    }
 	}
       else if(!strcmp((char *)data, "back"))
 	{
-	  gc_sound_play_ogg ("gobble", NULL);
 	  gc_bar_hide (TRUE);
 	  gc_board_stop();
 	}
       else if(!strcmp((char *)data, "help"))
 	{
-	  gc_sound_play_ogg ("gobble", NULL);
 	  gc_help_start(gcomprisBoard);
 	}
       else if(!strcmp((char *)data, "repeat"))
