@@ -17,7 +17,6 @@
 
 #ifdef ENABLE_BINRELOC
 	#include <sys/types.h>
-	#include <sys/stat.h>
 	#include <unistd.h>
 #endif /* ENABLE_BINRELOC */
 #include <glib/gstdio.h>
@@ -86,7 +85,7 @@ _br_find_exe (GbrInitError *error)
 
 		/* Check whether the symlink's target is also a symlink.
 		 * We want to get the final target. */
-		i = stat (path, &stat_buf);
+		i = g_stat (path, &stat_buf);
 		if (i == -1) {
 			/* Error. */
 			g_free (path2);
@@ -445,13 +444,14 @@ gchar *
 gbr_find_prefix (const gchar *default_prefix)
 {
 	gchar *dir1, *dir2;
+	extern gchar *exec_prefix;
 
 	if (exe == NULL) {
 		/* BinReloc not initialized. */
 		if (default_prefix != NULL)
 			return g_strdup (default_prefix);
 		else
-			return NULL;
+			return g_strdup (exec_prefix);
 	}
 
 	dir1 = g_path_get_dirname (exe);
