@@ -59,6 +59,7 @@ static gchar *linguas[] = {
   "",			N_("Your system default"),
   "am_ET.UTF-8", 	N_("Amharic"),
   "ar_AE.UTF-8", 	N_("Arabic"),
+  "ar_TN.UTF-8", 	N_("Arabic (Tunisia)"),
   "az_AZ.UTF-8", 	N_("Turkish (Azerbaijan)"),
   "bg_BG.UTF-8",	N_("Bulgarian"),
   "ca_ES.UTF-8",	N_("Catalan"),
@@ -68,19 +69,24 @@ static gchar *linguas[] = {
   "el_GR.UTF-8", 	N_("Greek"),
   "en_CA.UTF-8",	N_("English (Canada)"),
   "en_GB.UTF-8",	N_("English (Great Britain)"),
+  "en_US.UTF-8",	N_("English (United States)"),
   "es_ES.UTF-8", 	N_("Spanish"),
   "eu_ES.UTF-8",	N_("Basque"),
+  "dz_BT.UTF-8",	N_("Dzongkha"),
   "fi_FI.UTF-8", 	N_("Finnish"),
   "fr_FR.UTF-8", 	N_("French"),
   "ga_IE.UTF-8", 	N_("Irish (Gaelic)"),
   "he_IL.UTF-8",	N_("Hebrew"),
   "hi_IN.UTF-8",	N_("Hindi"),
+  "id_ID.UTF-8",	N_("Indonesian"),
+  "ja_JP.UTF-8",	N_("Japanese"),
   "gu_IN.UTF-8",	N_("Gujarati"),
   "pa_IN.UTF-8",	N_("Punjabi"),
   "hu_HU.UTF-8",	N_("Hungarian"),
   "hr_HR.UTF-8",	N_("Croatian"),
   "it_IT.UTF-8", 	N_("Italian"),
   "ka_GE.UTF-8",        N_("Georgian"),
+  "ko_KR.UTF-8",        N_("Korean"),
   "lt_LT.UTF-8",	N_("Lithuanian"),
   "mk_MK.UTF-8",	N_("Macedonian"),
   "ml_IN.UTF-8",	N_("Malayalam"),
@@ -90,6 +96,7 @@ static gchar *linguas[] = {
   "nl_NL.UTF-8",	N_("Dutch"),
   "nb_NO.UTF-8",	N_("Norwegian Bokmal"),
   "nn_NO.UTF-8",	N_("Norwegian Nynorsk"),
+  "oc_FR.UTF-8",	N_("Occitan (languedocien)"),
   "pl_PL.UTF-8",	N_("Polish"),
   "pt_PT.UTF-8",	N_("Portuguese"),
   "pt_BR.UTF-8",	N_("Portuguese (Brazil)"),
@@ -103,7 +110,7 @@ static gchar *linguas[] = {
   "sr@Latn_YU.ISO-8859-2",	N_("Serbian (Latin)"),
   "sr_YU.UTF-8",	N_("Serbian"),
   "sv_FI.UTF-8",	N_("Swedish"),
-  /*  "ta_IN.UTF-8",	N_("Tamil"), */
+  "ta_IN.UTF-8",	N_("Tamil"),
   "th_TH.UTF-8",	N_("Thai"),
   "tr_TR.UTF-8",	N_("Turkish"),
   "vi_VN.UTF-8",	N_("Vietnamese"),
@@ -745,13 +752,9 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	    {
 	      if(!properties->music)
 		sdlplayer_halt_music();
-	      else
-		sdlplayer_resume_music();
 
 	      if(!properties->fx)
 		sdlplayer_halt_fx();
-	      else
-		sdlplayer_resume_fx();
 	    }
 	  gc_prop_save(properties);
 	}
