@@ -18,7 +18,6 @@
  */
 
 #include <signal.h>
-#include <popt.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -26,14 +25,14 @@
 #include <time.h>
 #include <string.h>
 
+#include <glib/gstdio.h>
+
 #include "gcompris.h"
 #include "gc_core.h"
 #include "gcompris_config.h"
 #include "about.h"
 #include <locale.h>
 
-#include "cursor.h"
-
 #include "binreloc.h"
 
 /* For XF86_VIDMODE Support */
@@ -44,11 +43,26 @@
 #include <X11/extensions/xf86vmode.h>
 #endif
 
+/* for NSBUNDLE */
+#ifdef NSBUNDLE
+#include "gcompris-nsbundle.h"
+#endif
+
+/* get the default database name */
+#define DEFAULT_DATABASE "gcompris_sqlite.db"
+
+/* Multiple instance check */
+static gchar *lock_file;
+#define GC_LOCK_FILE "gcompris.lock"
+#define GC_LOCK_LIMIT 30 /* seconds */
+
 static GtkWidget *window;
 static GnomeCanvas *canvas;
 static GnomeCanvas *canvas_bar;
 static GnomeCanvas *canvas_bg;
 
+gchar * exec_prefix = NULL;
+
 //static gint pause_board_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
 static void map_cb  (GtkWidget *widget, gpointer data);
@@ -60,7 +74,7 @@ void gc_terminate(int signum);
 /*
  * For the Activation dialog
  */
-#ifdef WIN32
+#ifdef STATIC_MODULE
 int gc_activation_check(char *code);
 static void activation_enter_callback(GtkWidget *widget,
 				      GtkWidget *entry );
@@ -89,133 +103,133 @@ static gboolean		gc_debug = FALSE;
 /* Command line params */
 
 /*** gcompris-popttable */
-static int popt_fullscreen	   = FALSE;
-static int popt_window		   = FALSE;
-static int popt_sound		   = FALSE;
-static int popt_mute		   = FALSE;
-static int popt_cursor		   = FALSE;
-static int popt_version		   = FALSE;
-static int popt_aalias		   = FALSE;
-static int popt_difficulty_filter  = FALSE;
-static int popt_debug		   = FALSE;
-static int popt_noxf86vm	   = FALSE;
-static char *popt_root_menu        = NULL;
-static char *popt_local_activity   = NULL;
-static int popt_administration	   = FALSE;
-static char *popt_database         = NULL;
-static char *popt_logs_database    = NULL;
-static int popt_create_db   	   = FALSE;
-static int popt_reread_menu   	   = FALSE;
-static char *popt_profile	   = NULL;
-static int *popt_profile_list	   = FALSE;
-static char *popt_shared_dir	   = NULL;
-static char *popt_users_dir	   = NULL;
-static int  popt_experimental      = FALSE;
-static int  popt_no_quit	   = FALSE;
-static int  popt_no_config         = FALSE;
-static int  popt_display_resource  = FALSE;
-static char *popt_server            = NULL;
-static int  *popt_web_only          = NULL;
-static char *popt_cache_dir         = NULL;
+static gint popt_fullscreen	   = FALSE;
+static gint popt_window		   = FALSE;
+static gint popt_sound		   = FALSE;
+static gint popt_mute		   = FALSE;
+static gint popt_cursor		   = FALSE;
+static gint popt_version	   = FALSE;
+static gint popt_aalias		   = FALSE;
+static gint popt_difficulty_filter = FALSE;
+static gint popt_debug		   = FALSE;
+static gint popt_noxf86vm	   = FALSE;
+static gint popt_nobackimg	   = FALSE;
+static gint popt_nolockcheck	   = FALSE;
+static gchar *popt_root_menu       = NULL;
+static gchar *popt_local_activity  = NULL;
+static gint popt_administration	   = FALSE;
+static gchar *popt_database        = NULL;
+static gint popt_create_db   	   = FALSE;
+static gint popt_reread_menu   	   = FALSE;
+static gchar *popt_profile	   = NULL;
+static gint *popt_profile_list	   = FALSE;
+static gchar *popt_config_dir	   = NULL;
+static gchar *popt_user_dir	   = NULL;
+static gint  popt_experimental     = FALSE;
+static gint  popt_no_quit	   = FALSE;
+static gint  popt_no_config        = FALSE;
+static gint  popt_display_resource = FALSE;
+static gchar *popt_server          = NULL;
+static gint  *popt_web_only        = NULL;
+static gchar *popt_cache_dir       = NULL;
+static gchar *popt_drag_mode       = NULL;
 
-static struct poptOption options[] = {
-  {"fullscreen", 'f', POPT_ARG_NONE, &popt_fullscreen, 0,
+static GOptionEntry options[] = {
+  {"fullscreen", 'f', 0, G_OPTION_ARG_NONE, &popt_fullscreen,
    N_("run gcompris in fullscreen mode."), NULL},
 
-  {"window", 'w', POPT_ARG_NONE, &popt_window, 0,
+  {"window", 'w', 0, G_OPTION_ARG_NONE, &popt_window,
    N_("run gcompris in window mode."), NULL},
 
-  {"sound", 's', POPT_ARG_NONE, &popt_sound, 0,
+  {"sound", 's', 0, G_OPTION_ARG_NONE, &popt_sound,
    N_("run gcompris with sound enabled."), NULL},
 
-  {"mute", 'm', POPT_ARG_NONE, &popt_mute, 0,
+  {"mute", 'm', 0, G_OPTION_ARG_NONE, &popt_mute,
    N_("run gcompris without sound."), NULL},
 
-  {"cursor", 'c', POPT_ARG_NONE, &popt_cursor, 0,
+  {"cursor", 'c', 0, G_OPTION_ARG_NONE, &popt_cursor,
    N_("run gcompris with the default gnome cursor."), NULL},
 
-  {"difficulty", 'd', POPT_ARG_INT, &popt_difficulty_filter, 0,
+  {"difficulty", 'd', 0, G_OPTION_ARG_INT, &popt_difficulty_filter,
    N_("display only activities with this difficulty level."), NULL},
 
-  {"debug", 'D', POPT_ARG_NONE, &popt_debug, 0,
+  {"debug", 'D', 0, G_OPTION_ARG_NONE, &popt_debug,
    N_("display debug informations on the console."), NULL},
 
-  {"version", 'v', POPT_ARG_NONE, &popt_version, 0,
+  {"version", 'v', 0, G_OPTION_ARG_NONE, &popt_version,
    N_("Print the version of " PACKAGE), NULL},
 
-  {"antialiased", '\0', POPT_ARG_NONE, &popt_aalias, 0,
+  {"antialiased", '\0', 0, G_OPTION_ARG_NONE, &popt_aalias,
    N_("Use the antialiased canvas (slower)."), NULL},
 
-  {"noxf86vm", 'x', POPT_ARG_NONE, &popt_noxf86vm, 0,
+  {"noxf86vm", 'x', 0, G_OPTION_ARG_NONE, &popt_noxf86vm,
    N_("Disable XF86VidMode (No screen resolution change)."), NULL},
 
-  {"root-menu", 'l', POPT_ARG_STRING, &popt_root_menu, 0,
+  {"root-menu", 'l', 0, G_OPTION_ARG_STRING, &popt_root_menu,
    N_("Run gcompris with local menu (e.g -l /reading will let you play only activities in the reading directory, -l /strategy/connect4 only the connect4 activity)"), NULL},
 
-  {"local-activity", 'L', POPT_ARG_STRING, &popt_local_activity, 0,
+  {"local-activity", 'L', 0, G_OPTION_ARG_STRING, &popt_local_activity,
    N_("Run GCompris with local activity directory added to menu"), NULL},
 
-  {"administration", 'a', POPT_ARG_NONE, &popt_administration, 0,
+  {"administration", 'a', 0, G_OPTION_ARG_NONE, &popt_administration,
    N_("Run GCompris in administration and user-management mode"), NULL},
 
-  {"database", 'b', POPT_ARG_STRING, &popt_database, 0,
-   N_("Use alternate database for profiles"), NULL},
+  {"database", 'b', 0, G_OPTION_ARG_STRING, &popt_database,
+   N_("Use alternate database for profiles [$HOME/.config/gcompris/gcompris_sqlite.db]"), NULL},
 
-  {"logs", 'j', POPT_ARG_STRING, &popt_logs_database, 0,
-   N_("Use alternate database for logs"), NULL},
-
-  {"create-db",'\0', POPT_ARG_NONE, &popt_create_db, 0,
+  {"create-db",'\0', 0, G_OPTION_ARG_NONE, &popt_create_db,
    N_("Create the alternate database for profiles"), NULL},
 
-  {"reread-menu",'\0', POPT_ARG_NONE, &popt_reread_menu, 0,
+  {"reread-menu",'\0', 0, G_OPTION_ARG_NONE, &popt_reread_menu,
    N_("Re-read XML Menus and store them in the database"), NULL},
 
-  {"profile",'p', POPT_ARG_STRING, &popt_profile, 0,
+  {"profile",'p', 0, G_OPTION_ARG_STRING, &popt_profile,
    N_("Set the profile to use. Use 'gcompris -a' to create profiles"), NULL},
 
-  {"profile-list",'\0', POPT_ARG_NONE, &popt_profile_list, 0,
+  {"profile-list",'\0', 0, G_OPTION_ARG_NONE, &popt_profile_list,
    N_("List all available profiles. Use 'gcompris -a' to create profiles"), NULL},
 
-  {"shared-dir",'\0', POPT_ARG_STRING, &popt_shared_dir, 0,
-   N_("Shared directory location, for profiles and board-configuration data: [$HOME/.gcompris/shared]"), NULL},
+  {"config-dir",'\0', 0, G_OPTION_ARG_STRING, &popt_config_dir,
+   N_("Config directory location: [$HOME/.config/gcompris]. Alternate is to set $XDG_CONFIG_HOME."), NULL},
 
-  {"users-dir",'\0', POPT_ARG_STRING, &popt_users_dir, 0,
-   N_("The location of user directories: [$HOME/.gcompris/users]"), NULL},
+  {"user-dir",'\0', 0, G_OPTION_ARG_STRING, &popt_user_dir,
+   N_("The location of user directories: [$HOME/My GCompris]"), NULL},
 
-  {"experimental",'\0', POPT_ARG_NONE, &popt_experimental, 0,
+  {"experimental",'\0', 0, G_OPTION_ARG_NONE, &popt_experimental,
    N_("Run the experimental activities"), NULL},
 
-  {"disable-quit",'\0', POPT_ARG_NONE, &popt_no_quit, 0,
+  {"disable-quit",'\0', 0, G_OPTION_ARG_NONE, &popt_no_quit,
    N_("Disable the quit button"), NULL},
 
-  {"disable-config",'\0', POPT_ARG_NONE, &popt_no_config, 0,
+  {"disable-config",'\0', 0, G_OPTION_ARG_NONE, &popt_no_config,
    N_("Disable the config button"), NULL},
 
-  {"display-resource",'\0', POPT_ARG_NONE, &popt_display_resource, 0,
+#if 0 /* Never completed, this option means we should document resources
+	    of each activities which is boring to do */
+  {"display-resource",'\0', 0, G_OPTION_ARG_NONE, &popt_display_resource,
    N_("Display the resources on stdout based on the selected activities"), NULL},
+#endif
 
-  {"server", '\0', POPT_ARG_STRING, &popt_server, 0,
+  {"server", '\0', 0, G_OPTION_ARG_STRING, &popt_server,
    N_("GCompris will get images, sounds and activity data from this server if not found locally."), NULL},
 
-  {"web-only", '\0', POPT_ARG_NONE, &popt_web_only, 0,
+  {"web-only", '\0', 0, G_OPTION_ARG_NONE, &popt_web_only,
    N_("Only when --server is provided, disable check for local resource first."
       " Data are always taken from the web server."), NULL},
 
-  {"cache-dir", '\0', POPT_ARG_STRING, &popt_cache_dir, 0,
+  {"cache-dir", '\0', 0, G_OPTION_ARG_STRING, &popt_cache_dir,
    N_("In server mode, specify the cache directory used to avoid useless downloads."), NULL},
 
-#ifndef WIN32	/* Not supported on windows */
-  POPT_AUTOHELP
-#endif
-  {
-    NULL,
-    '\0',
-    0,
-    NULL,
-    0,
-    NULL,
-    NULL
-  }
+  {"drag-mode", 'g', 0, G_OPTION_ARG_STRING, &popt_drag_mode,
+   N_("Global drag and drop mode: normal, 2clicks, both. Default mode is normal."), NULL},
+
+  {"nobackimg", '\0', 0, G_OPTION_ARG_NONE, &popt_nobackimg,
+   N_("Do not display the background images of activities."), NULL},
+
+  {"nolockcheck", '\0', 0, G_OPTION_ARG_NONE, &popt_nolockcheck,
+   N_("Do not avoid the execution of multiple instances of GCompris."), NULL},
+
+  { NULL }
 };
 
 /* Fullscreen Stuff */
@@ -229,8 +243,7 @@ static struct
   int window_x;
   int window_y;
   gboolean fullscreen_active;
-  int ignore_focus_out;
-} XF86VidModeData = { { 0 }, { 0 }, 0, 0, 0, 0, FALSE, 0 };
+} XF86VidModeData = { { 0 }, { 0 }, 0, 0, 0, 0, FALSE };
 
 static void xf86_vidmode_init( void );
 static void xf86_vidmode_set_fullscreen( int state );
@@ -377,18 +390,19 @@ GtkWidget *gc_get_window()
   return window;
 }
 
-void gc_ignore_next_focus_out()
-{
-#ifdef XF86_VIDMODE
-  XF86VidModeData.ignore_focus_out++;
-#endif
-}
-
 GnomeCanvasItem *gc_set_background(GnomeCanvasGroup *parent, gchar *file)
 {
   GdkPixbuf *background_pixmap = NULL;
+  gchar *img = NULL;
 
-  background_pixmap = gc_pixmap_load (file);
+  if ( popt_nobackimg && (strncmp(file, "opt/", 4) == 0) )
+    {
+      img = gc_skin_image_get("gcompris-bg.jpg");
+      background_pixmap = gc_pixmap_load (img);
+      g_free(img);
+    }
+  else
+    background_pixmap = gc_pixmap_load (file);
 
   if(backgroundimg)
       gnome_canvas_item_set (backgroundimg,
@@ -530,7 +544,7 @@ static void init_background()
 
 void gc_cursor_set(guint gdk_cursor_type)
 {
-  GdkCursor *cursor;
+  GdkCursor *cursor = NULL;
 
   // Little hack to force gcompris to use the default cursor
   if(gdk_cursor_type==GCOMPRIS_DEFAULT_CURSOR)
@@ -542,55 +556,47 @@ void gc_cursor_set(guint gdk_cursor_type)
     gdk_window_set_cursor (window->window, cursor);
     gdk_cursor_destroy(cursor);
   } else { // we use a custom cursor
-    GdkColor fg, bg;
-    //    static const gchar * cursor;
-    static const gchar ** bits;
-
-    gdk_color_parse("rgb:FFFF/FFFF/FFFF",&fg);
-    gdk_color_parse("rgb:FFFF/3FFF/0000",&bg);
-
-    gdk_color_parse("black",&fg);
-    gdk_color_parse("red",&bg);
+    GdkPixbuf *cursor_pixbuf = NULL;
 
     switch (gdk_cursor_type) {
-    case GCOMPRIS_BIG_RED_ARROW_CURSOR :
-      bits = big_red_arrow_cursor_bits;
-      break;
-    case GCOMPRIS_BIRD_CURSOR :
-      bits = bird_cursor_bits;
+    case GCOMPRIS_DEFAULT_CURSOR :
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_default.png");
       break;
     case GCOMPRIS_LINE_CURSOR :
-      bits = big_red_line_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_line.png");
       break;
     case GCOMPRIS_RECT_CURSOR :
-      bits = big_red_rectangle_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_rect.png");
       break;
     case GCOMPRIS_FILLRECT_CURSOR :
-      bits = big_red_filledrectangle_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_fillrect.png");
       break;
     case GCOMPRIS_CIRCLE_CURSOR :
-      bits = big_red_circle_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_circle.png");
       break;
     case GCOMPRIS_FILLCIRCLE_CURSOR :
-      bits = big_red_filledcircle_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_fillcircle.png");
       break;
     case GCOMPRIS_FILL_CURSOR :
-      bits = big_red_fill_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_fill.png");
       break;
     case GCOMPRIS_DEL_CURSOR :
-      bits = big_red_del_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_del.png");
       break;
     case GCOMPRIS_SELECT_CURSOR :
-      bits = big_red_select_cursor_bits;
+      cursor_pixbuf = gc_skin_pixmap_load("cursor_select.png");
+      break;
+    default :
+      return;
       break;
-    default : bits = big_red_arrow_cursor_bits;
     }
 
-    cursor = gdk_cursor_new_from_data(bits, 40 , 40, &fg, &bg, 0, 0);
-    if(cursor)
+    if(cursor_pixbuf)
       {
+	cursor = gdk_cursor_new_from_pixbuf(gdk_display_get_default(), cursor_pixbuf, 0, 0);
 	gdk_window_set_cursor(window->window, cursor);
 	gdk_cursor_unref(cursor);
+	gdk_pixbuf_unref(cursor_pixbuf);
       }
   }
 }
@@ -785,7 +791,7 @@ static void setup_window ()
 
 }
 
-#ifdef WIN32
+#ifdef STATIC_MODULE
 extern int gc_board_number_in_demo;
 /** Display the activation dialog for the windows version
  *
@@ -835,7 +841,7 @@ display_activation_dialog()
 
   gc_board_stop();
 
-  char *msg = g_strdup_printf(_("GCompris is free software released under the GPL License. In order to support its development, the Windows version provides only %d of the %d activities. You can get the full version for a small fee at\n<http://gcompris.net>\nThe Linux version does not have this restriction. Note that GCompris is being developed to free schools from monopolistic software vendors. If you also believe that we should teach freedom to children, please consider using GNU/Linux. Get more information at FSF:\n<http://www.fsf.org/philosophy>"),
+  char *msg = g_strdup_printf(_("GCompris is free software released under the GPL License. In order to support its development, the Windows version provides only %d of the %d activities. You can get the full version for a small fee at\n<http://gcompris.net>\nThe GNU/Linux version does not have this restriction. Note that GCompris is being developed to free schools from monopolistic software vendors. If you also believe that we should teach freedom to children, please consider using GNU/Linux. Get more information at FSF:\n<http://www.fsf.org/philosophy>"),
 			      gc_board_number_in_demo, board_count);
   gc_dialog(msg, activation_done);
   g_free(msg);
@@ -924,7 +930,7 @@ activation_done()
       (strcmp((char *)gtk_entry_get_text(GTK_ENTRY(widget_activation_entry)), "GOOD") != 0) &&
       (strcmp((char *)gtk_entry_get_text(GTK_ENTRY(widget_activation_entry)), "WRONG") != 0))
     {
-      activation_enter_callback(widget_activation_entry, NULL);
+      activation_enter_callback(GTK_WIDGET(widget_activation_entry), NULL);
     }
 
   gc_board_play(properties->menu_board);
@@ -1027,6 +1033,7 @@ static void cleanup()
   gc_fullscreen_set(FALSE);
   gc_menu_destroy();
   gc_prop_destroy(gc_prop_get());
+  g_unlink(lock_file);
 }
 
 void gc_exit()
@@ -1095,18 +1102,18 @@ static void load_properties ()
   prefix_dir = gbr_find_prefix(NULL);
 
   /* Check if we are in the source code (developper usage) */
-  tmpstr = g_strconcat(prefix_dir, "/gcompris.c", NULL);
+  tmpstr = g_strconcat(prefix_dir, "/gcompris/gcompris.c", NULL);
   if(g_file_test(tmpstr, G_FILE_TEST_EXISTS))
     {
       /* Set all directory to get data from the source code we are run in */
-      properties->package_data_dir = g_strconcat(prefix_dir, "/../../boards", NULL);
+      properties->package_data_dir = g_strconcat(prefix_dir, "/../boards", NULL);
 
       /* In source code, locale mo files are not generated, use the installed one */
       properties->package_locale_dir = g_strdup(PACKAGE_LOCALE_DIR);
 
-      properties->package_plugin_dir = g_strconcat(prefix_dir, "/../boards/.libs", NULL);
-      properties->package_python_plugin_dir = g_strconcat(prefix_dir, "/../boards/python", NULL);
-      properties->system_icon_dir = g_strconcat(prefix_dir, "/../..", NULL);
+      properties->package_plugin_dir = g_strconcat(prefix_dir, "/boards/.libs", NULL);
+      properties->package_python_plugin_dir = g_strconcat(prefix_dir, "/boards/python", NULL);
+      properties->system_icon_dir = g_strconcat(prefix_dir, "/..", NULL);
     }
   else
     {
@@ -1130,7 +1137,6 @@ static void load_properties ()
   printf("package_locale_dir       = %s\n", properties->package_locale_dir);
   printf("package_plugin_dir       = %s\n", properties->package_plugin_dir);
   printf("package_python_plugin_dir= %s\n", properties->package_python_plugin_dir);
-
 }
 
 GcomprisProperties *gc_prop_get ()
@@ -1162,7 +1168,7 @@ const gchar *gc_locale_get()
 
   locale = g_getenv("LC_ALL");
   if(locale == NULL)
-    locale = g_getenv("LC_MESSAGES");
+    locale = g_getenv("LC_CTYPE");
   if(locale == NULL)
     locale = g_getenv("LANG");
 
@@ -1203,7 +1209,7 @@ gc_locale_set(gchar *locale)
   setlocale(LC_MESSAGES, locale);
   setlocale(LC_ALL, locale);
 #else
-  gc_locale = g_strdup(setlocale(LC_MESSAGES, locale));
+  gc_locale = g_strdup(setlocale(LC_CTYPE, locale));
   if (!gc_locale)
     gc_locale = g_strdup(locale);
 #endif
@@ -1217,7 +1223,7 @@ gc_locale_set(gchar *locale)
   /* Override the env locale to what the user requested */
   /* This makes gettext to give us the new locale text  */
   gc_setenv ("LC_ALL", gc_locale_get());
-  gc_setenv ("LC_MESSAGES", gc_locale_get());
+  gc_setenv ("LC_CTYPE", gc_locale_get());
   gc_setenv ("LANGUAGE", gc_locale_get());
   gc_setenv ("LANG", gc_locale_get());
 
@@ -1276,10 +1282,29 @@ xf86_vidmode_init ( void )
         gdk_screen_get_default()), &mode_count, &modes))
     properties->noxf86vm = TRUE;
   else {
+    unsigned short hdisplay;
+    unsigned short vdisplay;
+
+    /* Follow the use choice in the screen size resolution */
+    switch(properties->screensize)
+      {
+      case 0:
+	hdisplay = BOARDWIDTH * 0.8;
+	vdisplay = (BOARDHEIGHT+BARHEIGHT) * 0.8;
+	break;
+      case 2:
+	hdisplay = BOARDWIDTH * 1.28;
+	vdisplay = (BOARDHEIGHT+BARHEIGHT) * 1.28;
+	break;
+      default:
+	hdisplay = BOARDWIDTH;
+	vdisplay = BOARDHEIGHT+BARHEIGHT;
+	break;
+      }
     for (i = 0; i < mode_count; i++)
       {
-        if ((modes[i]->hdisplay == BOARDWIDTH) &&
-            (modes[i]->vdisplay == BOARDHEIGHT+BARHEIGHT))
+        if ((modes[i]->hdisplay == hdisplay) &&
+            (modes[i]->vdisplay == vdisplay))
           {
             XF86VidModeData.fs_mode = *modes[i];
             break;
@@ -1365,10 +1390,9 @@ static gint xf86_window_configured(GtkWindow *window,
 static gint xf86_focus_changed(GtkWindow *window,
   GdkEventFocus *event, gpointer param)
 {
-  if (!event->in && XF86VidModeData.ignore_focus_out)
-    XF86VidModeData.ignore_focus_out--;
-  else if (properties->fullscreen)
-    xf86_vidmode_set_fullscreen(event->in);
+  if(properties->fullscreen)
+    gdk_pointer_grab(event->window, TRUE, 0, event->window, NULL,
+		     GDK_CURRENT_TIME);
   /* Act as if we aren't there / aren't hooked up */
   return FALSE;
 }
@@ -1381,40 +1405,121 @@ static gint xf86_focus_changed(GtkWindow *window,
  */
 
 int
-gc_init (int argc, char *argv[])
+main (int argc, char *argv[])
 {
-  poptContext pctx;
-  int popt_option;
+  GError *error = NULL;
+  GOptionContext *context;
+
+  /* usefull for OSX bundle app */
+#ifdef NSBUNDLE
+  exec_prefix = gcompris_nsbundle_resource ();
+  printf("exec_prefix %s\n", exec_prefix);
+#else
+  exec_prefix = NULL;
+  printf("exec_prefix NULL\n");
+#endif
 
   /* First, Remove the gnome crash dialog because it locks the user when in full screen */
   signal(SIGSEGV, gc_terminate);
   signal(SIGINT, gc_terminate);
 
-  load_properties();
+#ifdef XF86_VIDMODE
+  printf("XF86VidMode: Compiled with XF86VidMode.\nIf you have problems starting GCompris in fullscreen, try the -x option to disable XF86VidMode.\n");
+#else
+  printf("XF86VidMode: Not compiled with XVIDMODE\n");
+#endif
 
-  gc_skin_load(properties->skin);
+  load_properties();
 
   bindtextdomain (GETTEXT_PACKAGE, properties->package_locale_dir);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
   /* To have some real random behaviour */
-  srand (time (NULL));
+  g_random_set_seed     (time (NULL));
 
   /* Default difficulty filter: non specified */
   popt_difficulty_filter = -1;
 
   gtk_init (&argc, &argv);
 
-  pctx = poptGetContext (PACKAGE, argc, (const char **)argv, options, 0);
-
   /* Argument parsing */
-  popt_option = poptGetNextOpt (pctx);
+  context = g_option_context_new("GCompris");
+  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+  g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free(context);
 
   // Set the default gcompris cursor
   properties->defaultcursor = GCOMPRIS_DEFAULT_CURSOR;
 
-  /* Save the default locale */
+  /* Set the default message handler, it avoids message with option -D */
+  g_log_set_handler (NULL, G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_WARNING | G_LOG_LEVEL_DEBUG | G_LOG_FLAG_FATAL
+		     | G_LOG_FLAG_RECURSION, gc_log_handler, NULL);
+
+  /*------------------------------------------------------------*/
+  if (popt_debug)
+    {
+      gc_debug = TRUE;
+    }
+
+  if (popt_config_dir)
+    {
+      printf("popt_config_dir\n");
+      if ((!g_file_test(popt_config_dir, G_FILE_TEST_IS_DIR)) ||
+	  (g_access(popt_config_dir, popt_administration? W_OK : R_OK ) == -1))
+	{
+	  printf("%s does not exists or is not %s", popt_config_dir,
+		 popt_administration? "writable" : "readable"	);
+	  exit(0);
+	}
+      else
+	{
+	  g_warning("Using %s as config directory.", popt_config_dir);
+	  g_free(properties->config_dir);
+	  properties->config_dir = g_strdup(popt_config_dir);
+	}
+    }
+
+  /* Now we know where our config file is, load the saved config */
+  gc_prop_load(properties);
+
+  /* Single instance Check */
+  lock_file = g_strdup_printf("%s/%s", properties->config_dir, GC_LOCK_FILE);
+  if(!popt_nolockcheck)
+    {
+      GTimeVal current_time;
+      g_get_current_time(&current_time);
+
+      if (g_file_test (lock_file, G_FILE_TEST_EXISTS))
+	{
+	  char *result;
+	  gsize length;
+	  glong seconds;
+	  /* Read it's content */
+	  g_file_get_contents(lock_file,
+			      &result,
+			      &length,
+			      NULL);
+	  sscanf(result, "%ld", &seconds);
+
+	  if(current_time.tv_sec - seconds < GC_LOCK_LIMIT)
+	    exit(0);
+	}
+
+      {
+	/* Update the date in it (in seconds) */
+	char date_str[64];
+	sprintf(date_str, "%ld", current_time.tv_sec);
+	g_file_set_contents(lock_file,
+			    date_str,
+			    strlen(date_str),
+			    NULL);
+      }
+    }
+
+
+  /* Set the locale */
 #if defined WIN32
   gc_user_default_locale = g_win32_getlocale();
   // Set the user's choice locale
@@ -1424,16 +1529,11 @@ gc_init (int argc, char *argv[])
     gc_locale_set(properties->locale);
   }
 #else
-  gc_user_default_locale = g_strdup(setlocale(LC_MESSAGES, NULL));
+  gc_user_default_locale = g_strdup(setlocale(LC_CTYPE, NULL));
   // Set the user's choice locale
   gc_locale_set(properties->locale);
 #endif
 
-  /* Set the default message handler, it avoids message with option -D */
-  g_log_set_handler (NULL, G_LOG_LEVEL_MESSAGE | G_LOG_LEVEL_WARNING | G_LOG_LEVEL_DEBUG | G_LOG_FLAG_FATAL
-		     | G_LOG_FLAG_RECURSION, gc_log_handler, NULL);
-
-  /*------------------------------------------------------------*/
   if (popt_version)
     {
       printf (_("GCompris\nVersion: %s\nLicence: GPL\n"
@@ -1442,11 +1542,6 @@ gc_init (int argc, char *argv[])
       exit (0);
     }
 
-  if (popt_debug)
-    {
-      gc_debug = TRUE;
-    }
-
   if (popt_fullscreen)
     {
       properties->fullscreen = TRUE;
@@ -1527,7 +1622,6 @@ gc_init (int argc, char *argv[])
       /* check the list of possible values for -l, then exit */
       printf(_("Use -l to access an activity directly.\n"));
       printf(_("The list of available activities is :\n"));
-      properties->root_menu = "/";
 
       gc_db_init();
 
@@ -1564,44 +1658,28 @@ gc_init (int argc, char *argv[])
       exit(0);
     }
     else {
-    g_warning("Using menu %s as root.", popt_root_menu);
-    properties->root_menu = g_strdup(popt_root_menu);
-    properties->menu_position = g_strdup(popt_root_menu);
+      g_warning("Using menu %s as root.", popt_root_menu);
+      g_free(properties->root_menu);
+      properties->root_menu = g_strdup(popt_root_menu);
     }
   }
 
-  if (popt_users_dir){
-    if ((!g_file_test(popt_users_dir, G_FILE_TEST_IS_DIR)) ||
-	(access(popt_users_dir, popt_administration? R_OK : W_OK ) == -1)){
-	g_warning("%s does not exists or is not %s ", popt_users_dir,
-		  popt_administration? "readable" : "writable");
-	exit(0);
-    } else {
-      g_warning("Using %s as users directory.", popt_users_dir);
-      properties->users_dir = g_strdup(popt_users_dir);
+  if (popt_user_dir)
+    {
+      if ((!g_file_test(popt_user_dir, G_FILE_TEST_IS_DIR)) ||
+	  (g_access(popt_user_dir, popt_administration? R_OK : W_OK ) == -1))
+	{
+	  g_warning("%s does not exists or is not %s ", popt_user_dir,
+		    popt_administration? "readable" : "writable");
+	  exit(0);
+	}
+      else
+	{
+	  g_warning("Using %s as user directory.", popt_user_dir);
+	  g_free(properties->user_dir);
+	  properties->user_dir = g_strdup(popt_user_dir);
+	}
     }
-  }
-
-  if (popt_shared_dir){
-    if ((!g_file_test(popt_shared_dir, G_FILE_TEST_IS_DIR)) ||
-	(access(popt_shared_dir, popt_administration? W_OK : R_OK ) == -1)){
-      g_warning("%s does not exists or is not %s", popt_shared_dir,
-		popt_administration? "writable" : "readable"	);
-      exit(0);
-    }
-    else {
-      g_warning("Using %s as shared directory.", popt_shared_dir);
-      properties->shared_dir = g_strdup(popt_shared_dir);
-    }
-  }
-
-  /* shared_dir initialised, now we can set the default */
-  g_free(properties->database);
-  properties->database = gc_prop_default_database_name_get ( properties->shared_dir );
-  g_warning( "Infos:\n   Shared dir '%s'\n   Users dir '%s'\n   Database '%s'\n",
-	     properties->shared_dir,
-	     properties->users_dir,
-	     properties->database);
 
   if (popt_database)
     {
@@ -1609,22 +1687,30 @@ gc_init (int argc, char *argv[])
 
       if (g_file_test(properties->database, G_FILE_TEST_EXISTS))
 	{
-	  if (access(properties->database, R_OK)==-1)
+	  if (g_access(properties->database, R_OK)==-1)
 	    {
-	      g_warning("%s exists but is not readable or writable", properties->database);
+	      printf("%s exists but is not readable or writable", properties->database);
 	      exit(0);
 	    }
-	  else
-	    {
-	      g_warning("Using %s as database", properties->database);
-	    }
 	}
     }
+  else
+    {
+      /* Init the default database location */
+      properties->database = g_strconcat(properties->config_dir,
+					 "/", DEFAULT_DATABASE, NULL);
+    }
+
+  /* config_dir initialised, now we can set the default */
+  printf("Infos:\n   Config dir '%s'\n   Users dir '%s'\n   Database '%s'\n",
+	 properties->config_dir,
+	 properties->user_dir,
+	 properties->database);
 
   if (popt_create_db)
     {
       gchar *dirname = g_path_get_dirname (properties->database);
-      if (access(dirname, W_OK)==-1)
+      if (g_access(dirname, W_OK)==-1)
 	{
 	  g_warning("Cannot create %s : %s is not writable !", properties->database, dirname);
 	  exit (0);
@@ -1636,22 +1722,24 @@ gc_init (int argc, char *argv[])
 
   if (popt_administration){
     if (popt_database){
-      if (access(popt_database,R_OK|W_OK)==-1){
+      if (g_access(popt_database,R_OK|W_OK)==-1){
 	g_warning("%s exists but is not writable", popt_database);
 	exit(0);
       }
     }
     g_warning("Running in administration mode");
     properties->administration = TRUE;
-    g_warning("Background music disabled");
+    g_warning("Music disabled");
     properties->music = FALSE;
-    g_warning("Fullscreen is disabled");
+    properties->fx = FALSE;
+    g_warning("Fullscreen and cursor is disabled");
     properties->fullscreen = FALSE;
+    properties->defaultcursor = GDK_LEFT_PTR;
   }
 
   if (popt_reread_menu){
     g_warning("Rebuild db from xml files");
-    if (access(properties->database, W_OK)==-1)
+    if (g_access(properties->database, W_OK)==-1)
       g_warning("Cannot reread menu when database is read-only !");
     else
       properties->reread_menu = TRUE;
@@ -1678,6 +1766,22 @@ gc_init (int argc, char *argv[])
       properties->cache_dir = g_strdup(popt_cache_dir);
   }
 
+  if (popt_drag_mode){
+    if (strcmp(popt_drag_mode, "default") == 0)
+      properties->drag_mode = GC_DRAG_MODE_GRAB;
+    else {
+      if (strcmp(popt_drag_mode, "2clicks") == 0)
+	properties->drag_mode = GC_DRAG_MODE_2CLICKS;
+      else {
+	if (strcmp(popt_drag_mode, "both") == 0)
+	  properties->drag_mode = GC_DRAG_MODE_BOTH;
+	else g_warning("Unknown drag mode ! Valids modes are \"normal\", \"2clicks\" and \"both\"");
+      }
+    }
+  }
+
+  gc_prop_activate(properties);
+
   /*
    * Database init MUST BE after properties
    * And after a possible alternate database as been provided
@@ -1725,9 +1829,10 @@ gc_init (int argc, char *argv[])
     exit(0);
   }
 
-  poptFreeContext(pctx);
   /*------------------------------------------------------------*/
 
+  gc_skin_load(properties->skin);
+
   if(properties->music || properties->fx)
     gc_sound_init();
 
@@ -1744,11 +1849,16 @@ gc_init (int argc, char *argv[])
 
   gtk_widget_show_all (window);
 
-  if (properties->music)
-    gc_sound_play_ogg("music/intro.ogg", "sounds/$LOCALE/misc/welcome.ogg", NULL);
-  else
-    gc_sound_play_ogg("sounds/$LOCALE/misc/welcome.ogg", NULL);
+  /* If a specific activity is selected, skeep the intro music */
+  if(!popt_root_menu)
+    {
+      if (properties->music)
+	gc_sound_play_ogg("music/intro.ogg", "sounds/$LOCALE/misc/welcome.ogg", NULL);
+      else
+	gc_sound_play_ogg("sounds/$LOCALE/misc/welcome.ogg", NULL);
+    }
 
   gtk_main ();
-  return 0;
+
+  return(0);
 }
