@@ -1,6 +1,6 @@
 /* gcompris - gcompris.h
  *
- * Time-stamp: <2006/03/02 00:02:09 bruno>
+ * Time-stamp: <2006/08/20 10:03:53 bruno>
  *
  * Copyright (C) 2000,2001,2002 Bruno Coudoin
  *
@@ -42,6 +42,7 @@
 #include "board_config.h"
 #include "properties.h"
 #include "gameutil.h"
+#include "gc_net.h"
 #include "bonus.h"
 #include "timer.h"
 #include "score.h"
@@ -50,11 +51,12 @@
 
 #include "profile.h"
 #include "gcompris_db.h"
-#include "gcompris_files.h"
 #include "wordlist.h"
 #include "gcompris_im.h"
 #include "gcompris_alphabeta.h"
 
+#include "drag.h"
+
 #ifdef USE_CAIRO
 #include "gcompris-cairo.h"
 #endif
@@ -79,25 +81,25 @@
 /*****************************************************************************/
 /* Method usefull for boards provided by gcompris */
 
-void		 gcompris_end_board(void);
+void		 gc_board_end(void);
 
 /* Control Bar methods */
-void		 gcompris_bar_start (GnomeCanvas *theCanvas);
+void		 gc_bar_start (GnomeCanvas *theCanvas);
 
-GnomeCanvasItem *gcompris_set_background(GnomeCanvasGroup *parent, gchar *file);
-void		 gcompris_bar_set_level (GcomprisBoard *gcomprisBoard);
-void		 gcompris_bar_set_repeat_icon (GdkPixbuf *pixmap);
+GnomeCanvasItem *gc_set_background(GnomeCanvasGroup *parent, gchar *file);
+void		 gc_bar_set_level (GcomprisBoard *gcomprisBoard);
+void		 gc_bar_set_repeat_icon (GdkPixbuf *pixmap);
 
 /* Status bar control */
 typedef enum
 {
-  GCOMPRIS_BAR_LEVEL	   = 1 << 0,
-  GCOMPRIS_BAR_OK	   = 1 << 1,
-  GCOMPRIS_BAR_REPEAT	   = 1 << 2,
-  GCOMPRIS_BAR_CONFIG	   = 1 << 3,
-  GCOMPRIS_BAR_ABOUT	   = 1 << 4,
-  GCOMPRIS_BAR_REPEAT_ICON = 1 << 5,
-  GCOMPRIS_BAR_QUIT	   = 1 << 6,
+  GC_BAR_LEVEL	   = 1 << 0,
+  GC_BAR_OK	   = 1 << 1,
+  GC_BAR_REPEAT	   = 1 << 2,
+  GC_BAR_CONFIG	   = 1 << 3,
+  GC_BAR_ABOUT	   = 1 << 4,
+  GC_BAR_REPEAT_ICON = 1 << 5,
+  GC_BAR_QUIT	   = 1 << 6,
 } GComprisBarFlags;
 
 /* Difficulty filtering */
@@ -108,72 +110,71 @@ typedef enum {
   GCOMPRIS_FILTER_ABOVE,
 } GcomprisFilterType;
 
-void		 gcompris_bar_set (const GComprisBarFlags flags);
-void		 gcompris_bar_hide (gboolean hide);
-
-/* Help window */
-gboolean	 gcompris_board_has_help (GcomprisBoard *gcomprisBoard);
-void		 gcompris_help_start (GcomprisBoard *gcomprisBoard);
-void		 gcompris_help_stop (void);
+void		 gc_bar_set (const GComprisBarFlags flags);
+void		 gc_bar_hide (gboolean hide);
 
 /* General */
-GnomeCanvas     *gcompris_get_canvas(void);
-GtkWidget	*gcompris_get_window(void);
+GnomeCanvas     *gc_get_canvas(void);
+GtkWidget	*gc_get_window(void);
 
-const gchar	*gcompris_get_locale(void);
-void		 gcompris_set_locale(gchar *locale);
-char		*gcompris_get_user_default_locale(void);
+const gchar	*gc_locale_get(void);
+void		 gc_locale_set(gchar *locale);
+char		*gc_locale_get_user_default(void);
+gchar		*gc_locale_get_name(gchar *locale);
 
-void		 gcompris_set_cursor(guint gdk_cursor_type);
+void		 gc_cursor_set(guint gdk_cursor_type);
 
 typedef void     (*ImageSelectorCallBack)     (gchar* image);
-void		 gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, 
-						 gchar *dataset, 
+void		 gc_selector_images_start (GcomprisBoard *gcomprisBoard,
+						 gchar *dataset,
 						 ImageSelectorCallBack imscb);
-void		 gcompris_images_selector_stop (void);
+void		 gc_selector_images_stop (void);
 
 typedef void     (*FileSelectorCallBack)     (gchar *file, gchar *file_type); /* file_type is one string from file_types in the save */
-void		 gcompris_file_selector_load (GcomprisBoard *gcomprisBoard, 
+void		 gc_selector_file_load (GcomprisBoard *gcomprisBoard,
 					      gchar *rootdir,
 					      gchar *file_types, /* A Comma separated text explaining the different file types */
 					      FileSelectorCallBack fscb);
-void		 gcompris_file_selector_save (GcomprisBoard *gcomprisBoard,
+void		 gc_selector_file_save (GcomprisBoard *gcomprisBoard,
 					      gchar *rootdir,
 					      gchar *file_types, /* A Comma separated text explaining the different file types */
 					      FileSelectorCallBack fscb);
-void		 gcompris_file_selector_stop (void);
+void		 gc_selector_file_stop (void);
 
-void		 gcompris_set_fullscreen(gboolean state);
+gchar		*gc_db_get_filename();
 
-void		 gcompris_exit();
-
-gchar		*gcompris_get_database();
+/* Dialog box */
+typedef void     (*DialogBoxCallBack)     ();
+void		 gc_dialog(gchar *str, DialogBoxCallBack dbcb);
+void		 gc_dialog_close();
 
+/* Confirm box */
 typedef void     (*ConfirmCallBack)     (gboolean answer);
 
-void gcompris_confirm (gchar *title, 
-		       gchar *question_text,
-		       gchar *yes_text,
-		       gchar *no_text,
-		       ConfirmCallBack iscb);
+void		 gc_confirm_box (gchar *title,
+				 gchar *question_text,
+				 gchar *yes_text,
+				 gchar *no_text,
+				 ConfirmCallBack iscb);
 
-void gcompris_confirm_stop (void);
+void		 gc_confirm_box_stop (void);
 
-/* Trace Log */
-#define GCOMPRIS_LOG_STATUS_PASSED    "PASSED"
-#define GCOMPRIS_LOG_STATUS_FAILED    "FAILED"
-#define GCOMPRIS_LOG_STATUS_DRAW      "DRAW"
-#define GCOMPRIS_LOG_STATUS_COMPLETED "COMPLETED"
-
-/* gcompris internal only */
-void gcompris_log_start (GcomprisBoard *gcomprisBoard); 
-void gcompris_log_set_key (GcomprisBoard *gcomprisBoard, guint keyval);
+/* Use these instead of the gnome_canvas ones for proper fullscreen mousegrab
+   handling. */
+int		 gc_canvas_item_grab (GnomeCanvasItem *item, unsigned int event_mask,
+				      GdkCursor *cursor, guint32 etime);
+void		 gc_canvas_item_ungrab (GnomeCanvasItem *item, guint32 etime);
 
 /* Use it to tell the teacher where the kid failed */
-void gcompris_log_set_comment (GcomprisBoard *gcomprisBoard, gchar *expected, gchar* got); 
+void		 gc_log_set_comment (GcomprisBoard *gcomprisBoard, gchar *expected, gchar* got);
 
 /* Do not use it if you use the bonus API in your board */
-void gcompris_log_end (GcomprisBoard *gcomprisBoard, gchar *status);
+void		 gc_log_end (GcomprisBoard *gcomprisBoard, GCBonusStatusList status);
+
+/* For menu type activity */
+GList		*gc_menu_getlist(gchar *section);
+GcomprisBoard   *gc_menu_section_get(gchar *section);
+GList           *gc_menu_get_boards();
 
 /*=========================================================*/
 /* Some global definition to keep a constant look and feel */
@@ -206,8 +207,7 @@ void gcompris_log_end (GcomprisBoard *gcomprisBoard, gchar *status);
 // These are gcompris defined cursors
 // cursor defines must be over the last gnome cursor defined in gdkcursors.h
 #define GCOMPRIS_FIRST_CUSTOM_CURSOR	1000
-#define GCOMPRIS_BIG_RED_ARROW_CURSOR	1001
-#define GCOMPRIS_BIRD_CURSOR		1002
+#define GCOMPRIS_DEFAULT_CURSOR		1001
 #define GCOMPRIS_LINE_CURSOR		1003
 #define GCOMPRIS_FILLRECT_CURSOR	1004
 #define GCOMPRIS_RECT_CURSOR		1005
@@ -217,14 +217,4 @@ void gcompris_log_end (GcomprisBoard *gcomprisBoard, gchar *status);
 #define GCOMPRIS_FILL_CURSOR		1009
 #define GCOMPRIS_SELECT_CURSOR		1010
 
-#define GCOMPRIS_DEFAULT_CURSOR		GCOMPRIS_BIG_RED_ARROW_CURSOR
-
 #endif
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
