@@ -1,6 +1,6 @@
 /* gcompris - gcompris_im.h
  *
- * Time-stamp: <2005/10/02 22:12:39 bruno>
+ * Time-stamp: <2006/08/29 01:18:09 bruno>
  *
  * Copyright (C) 2005 Bruno Coudoin
  *
@@ -26,19 +26,7 @@
 #ifndef GCOMPRIS_IM_H
 #define GCOMPRIS_IM_H
 
-void gcompris_im_init();
-
-void gcompris_board_change_context();
-
-void gcompris_im_reset();
+void gc_im_init();
+void gc_im_reset();
 
 #endif
-
-
-/* Local Variables: */
-/* mode:c */
-/* eval:(load-library "time-stamp") */
-/* eval:(make-local-variable 'write-file-hooks) */
-/* eval:(add-hook 'write-file-hooks 'time-stamp) */
-/* eval:(setq time-stamp-format '(time-stamp-yyyy/mm/dd time-stamp-hh:mm:ss user-login-name)) */
-/* End: */
